@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ namespace KeePass.DataExchange
 {
 	public sealed class CsvStreamReader
 	{
-		private CharStream m_sChars;
+		private readonly CharStream m_sChars;
 		private readonly bool m_bAllowUnquoted;
 
 		[Obsolete]
@@ -95,7 +95,7 @@ namespace KeePass.DataExchange
 			if((chFirst == '\r') || (chFirst == '\n'))
 			{
 				m_sChars.ReadChar(); // Advance
-				return new string[0];
+				return MemUtil.EmptyArray<string>();
 			}
 
 			List<string> v = new List<string>();
