@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,20 +20,20 @@
 using System;
 using System.Collections.Generic;
 using System.Diagnostics;
-using System.Drawing;
+using System.Globalization;
 using System.IO;
 using System.Text;
 
 using KeePass.Resources;
+using KeePass.Util;
 
 using KeePassLib;
 using KeePassLib.Interfaces;
-using KeePassLib.Security;
 using KeePassLib.Utility;
 
 namespace KeePass.DataExchange.Formats
 {
-	// 1.12+
+	// 1.12-2024.4.3+
 	internal sealed class BitwardenJson112 : FileFormatProvider
 	{
 		public override bool SupportsImport { get { return true; } }
@@ -43,39 +43,42 @@ namespace KeePass.DataExchange.Formats
 		public override string DefaultExtension { get { return "json"; } }
 		public override string ApplicationGroup { get { return KPRes.PasswordManagers; } }
 
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_Imp_Bitwarden; }
-		}
-
 		public override void Import(PwDatabase pwStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
 			using(StreamReader sr = new StreamReader(sInput, StrUtil.Utf8, true))
 			{
 				string str = sr.ReadToEnd();
-				if(!string.IsNullOrEmpty(str))
-				{
-					CharStream cs = new CharStream(str);
-					ImportRoot(new JsonObject(cs), pwStorage);
-				}
+				if(string.IsNullOrEmpty(str)) return;
+
+				CharStream cs = new CharStream(str);
+				ImportRoot(new JsonObject(cs), pwStorage);
 			}
 		}
 
 		private static void ImportRoot(JsonObject jo, PwDatabase pd)
 		{
+			if(jo.GetValue<bool>("encrypted", false))
+				throw new FormatException(KPRes.NoEncNoCompress);
+
 			Dictionary<string, PwGroup> dGroups = new Dictionary<string, PwGroup>();
 			JsonObject[] vGroups = jo.GetValueArray<JsonObject>("folders");
 			if(vGroups != null) ImportGroups(vGroups, dGroups, pd);
 			dGroups[string.Empty] = pd.RootGroup; // Also when vGroups is null
 
+			Dictionary<string, string> dCollections = new Dictionary<string, string>();
+			JsonObject[] vCollections = jo.GetValueArray<JsonObject>("collections");
+			if(vCollections != null) ImportCollections(vCollections, dCollections);
+
 			JsonObject[] vEntries = jo.GetValueArray<JsonObject>("items");
-			if(vEntries != null) ImportEntries(vEntries, dGroups, pd);
+			if(vEntries != null) ImportEntries(vEntries, dGroups, dCollections, pd);
 		}
 
 		private static void ImportGroups(JsonObject[] vGroups,
 			Dictionary<string, PwGroup> dGroups, PwDatabase pd)
 		{
+			char[] vSep = new char[] { '/' };
+
 			foreach(JsonObject jo in vGroups)
 			{
 				if(jo == null) { Debug.Assert(false); continue; }
@@ -83,27 +86,40 @@ namespace KeePass.DataExchange.Formats
 				string strID = (jo.GetValue<string>("id") ?? string.Empty);
 				string strName = (jo.GetValue<string>("name") ?? string.Empty);
 
-				PwGroup pg = new PwGroup(true, true);
-				pg.Name = strName;
+				dGroups[strID] = pd.RootGroup.FindCreateSubTree(strName, vSep);
+			}
+		}
 
-				pd.RootGroup.AddGroup(pg, true);
-				dGroups[strID] = pg;
+		private static void ImportCollections(JsonObject[] vCollections,
+			Dictionary<string, string> dCollections)
+		{
+			foreach(JsonObject jo in vCollections)
+			{
+				if(jo == null) { Debug.Assert(false); continue; }
+
+				string strID = jo.GetValue<string>("id");
+				string strName = jo.GetValue<string>("name");
+
+				if(!string.IsNullOrEmpty(strID) && !string.IsNullOrEmpty(strName))
+					dCollections[strID] = strName.Replace("/", " / ");
+				else { Debug.Assert(false); }
 			}
 		}
 
 		private static void ImportEntries(JsonObject[] vEntries,
-			Dictionary<string, PwGroup> dGroups, PwDatabase pd)
+			Dictionary<string, PwGroup> dGroups, Dictionary<string, string> dCollections,
+			PwDatabase pd)
 		{
 			foreach(JsonObject jo in vEntries)
 			{
 				if(jo == null) { Debug.Assert(false); continue; }
 
-				ImportEntry(jo, dGroups, pd);
+				ImportEntry(jo, dGroups, dCollections, pd);
 			}
 		}
 
 		private static void ImportEntry(JsonObject jo, Dictionary<string, PwGroup> dGroups,
-			PwDatabase pd)
+			Dictionary<string, string> dCollections, PwDatabase pd)
 		{
 			PwEntry pe = new PwEntry(true, true);
 
@@ -113,11 +129,21 @@ namespace KeePass.DataExchange.Formats
 			if(pg == null) { Debug.Assert(false); pg = dGroups[string.Empty]; }
 			pg.AddEntry(pe, true);
 
+			foreach(string strID in jo.GetValueArray<string>("collectionIds", true))
+			{
+				if(string.IsNullOrEmpty(strID)) { Debug.Assert(false); continue; }
+
+				string strName;
+				if(dCollections.TryGetValue(strID, out strName))
+					pe.AddTag(strName);
+				else { Debug.Assert(false); }
+			}
+
 			ImportString(jo, "name", pe, PwDefs.TitleField, pd);
 			ImportString(jo, "notes", pe, PwDefs.NotesField, pd);
 
 			bool bFav = jo.GetValue<bool>("favorite", false);
-			if(bFav) pe.AddTag("Favorite");
+			if(bFav) pe.AddTag(PwDefs.FavoriteTag);
 
 			JsonObject joSub = jo.GetValue<JsonObject>("login");
 			if(joSub != null) ImportLogin(joSub, pe, pd);
@@ -137,27 +163,27 @@ namespace KeePass.DataExchange.Formats
 			ImportString(jo, "username", pe, PwDefs.UserNameField, pd);
 			ImportString(jo, "password", pe, PwDefs.PasswordField, pd);
 
-			ImportString(jo, "totp", pe, "TOTP", pd);
-			ProtectedString ps = pe.Strings.Get("TOTP");
-			if(ps != null) pe.Strings.Set("TOTP", ps.WithProtection(true));
-
-			JsonObject[] vUris = jo.GetValueArray<JsonObject>("uris");
-			if(vUris != null)
+			// https://bitwarden.com/help/authenticator-keys/
+			string strOtp = jo.GetValue<string>("totp");
+			if((strOtp != null) && strOtp.StartsWith(EntryUtil.OtpAuthScheme + ":",
+				StrUtil.CaseIgnoreCmp))
 			{
-				int iUri = 1;
-				foreach(JsonObject joUri in vUris)
-				{
-					if(joUri == null) { Debug.Assert(false); continue; }
+				try { EntryUtil.ImportOtpAuth(pe, strOtp, pd); }
+				catch(Exception) { Debug.Assert(false); }
+			}
+			else // Null, Steam URI, ...
+			{
+				ImportString(jo, "totp", pe, "TOTP", pd);
+				pe.Strings.EnableProtection("TOTP", true);
+			}
 
-					string str = joUri.GetValue<string>("uri");
-					if(!string.IsNullOrEmpty(str))
-					{
-						ImportUtil.AppendToField(pe, ((iUri == 1) ?
-							PwDefs.UrlField : ("URL " + iUri.ToString())),
-							str, pd);
-						++iUri;
-					}
-				}
+			foreach(JsonObject joUri in jo.GetValueArray<JsonObject>("uris", true))
+			{
+				if(joUri == null) { Debug.Assert(false); continue; }
+
+				string str = joUri.GetValue<string>("uri");
+				ImportUtil.CreateFieldWithIndex(pe.Strings, PwDefs.UrlField,
+					str, pd, false);
 			}
 		}
 
@@ -170,7 +196,9 @@ namespace KeePass.DataExchange.Formats
 
 			int iYear, iMonth;
 			string strYear = (jo.GetValue<string>("expYear") ?? string.Empty);
-			int.TryParse(strYear, out iYear);
+			if(!int.TryParse(strYear, out iYear)) iYear = -1;
+			if((iYear >= 0) && (iYear <= 99))
+				iYear = CultureInfo.CurrentCulture.Calendar.ToFourDigitYear(iYear);
 			if((iYear >= 1) && (iYear <= 9999))
 			{
 				string strMonth = (jo.GetValue<string>("expMonth") ?? string.Empty);
@@ -190,7 +218,7 @@ namespace KeePass.DataExchange.Formats
 				if(jo == null) { Debug.Assert(false); continue; }
 
 				string strName = jo.GetValue<string>("name");
-				string strValue = jo.GetValue<string>("value");
+				string strValue = (jo.GetValue<string>("value") ?? string.Empty);
 				long lType = jo.GetValue<long>("type", 0);
 
 				if(!string.IsNullOrEmpty(strName))
@@ -198,11 +226,7 @@ namespace KeePass.DataExchange.Formats
 					ImportUtil.AppendToField(pe, strName, strValue, pd);
 
 					if((lType == 1) && !PwDefs.IsStandardField(strName))
-					{
-						ProtectedString ps = pe.Strings.Get(strName);
-						if(ps == null) { Debug.Assert(false); }
-						else pe.Strings.Set(strName, ps.WithProtection(true));
-					}
+						pe.Strings.EnableProtection(strName, true);
 				}
 				else { Debug.Assert(false); }
 			}
