@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,10 +19,9 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
 using System.Diagnostics;
-using System.Drawing;
 using System.IO;
+using System.Text;
 
 using KeePassLib;
 using KeePassLib.Delegates;
@@ -41,13 +40,6 @@ namespace KeePass.DataExchange.Formats
 		public override string DefaultExtension { get { return "csv"; } }
 		public override string ApplicationGroup { get { return PwDefs.ShortProductName; } }
 
-		// public override bool ImportAppendsToRootGroupOnly { get { return true; } }
-
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_KeePass; }
-		}
-
 		/* public override void Import(PwDatabase pwStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
@@ -59,8 +51,7 @@ namespace KeePass.DataExchange.Formats
 
 			while(true)
 			{
-				if(ReadEntry(pwStorage, csSource) == false)
-					break;
+				if(!ReadEntry(pwStorage, csSource)) break;
 			}
 		}
 
