@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@ using System.Collections.Generic;
 using System.Drawing;
 using System.IO;
 using System.Text;
-using System.Windows.Forms;
 
 using KeePass.Resources;
 
@@ -42,8 +41,8 @@ namespace KeePass.DataExchange.Formats
 		public override string DefaultExtension { get { return KeePassKdb1x.FileExt1; } }
 		public override string ApplicationGroup { get { return PwDefs.ShortProductName; } }
 
-		public override bool SupportsUuids { get { return true; } }
 		public override bool RequiresKey { get { return true; } }
+		public override bool SupportsUuids { get { return true; } }
 
 		public override Image SmallIcon
 		{
@@ -110,9 +109,10 @@ namespace KeePass.DataExchange.Formats
 				sOutput.Write(pbKdb, 0, pbKdb.Length);
 				MemUtil.ZeroByteArray(pbKdb);
 			}
-			catch(Exception exKdb)
+			catch(Exception ex)
 			{
-				if(slLogger != null) slLogger.SetText(exKdb.Message, LogStatusType.Error);
+				if(slLogger != null)
+					slLogger.SetText(StrUtil.FormatException(ex, null), LogStatusType.Error);
 
 				return false;
 			}
