@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,12 +19,11 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
-using System.Drawing;
+using System.Diagnostics;
 using System.IO;
+using System.Text;
 using System.Xml;
 using System.Xml.Serialization;
-using System.Diagnostics;
 
 using KeePass.Resources;
 using KeePass.Util;
@@ -50,11 +49,6 @@ namespace KeePass.DataExchange.Formats
 
 		public override bool SupportsUuids { get { return false; } }
 
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_Imp_KeePassX; }
-		}
-
 		private const string ElemRoot = "database";
 
 		private const string ElemGroup = "group";
