@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,11 +19,11 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
-using System.Windows.Forms;
-using System.IO;
 using System.Drawing;
+using System.IO;
+using System.Text;
 using System.Threading;
+using System.Windows.Forms;
 
 using KeePass.App;
 using KeePass.Native;
@@ -46,19 +46,19 @@ namespace KeePass.DataExchange.Formats
 		public override string FormatName { get { return "PassKeeper"; } }
 		public override string ApplicationGroup { get { return KPRes.PasswordManagers; } }
 
-		public override bool RequiresFile { get { return false; } }
 		public override bool ImportAppendsToRootGroupOnly { get { return true; } }
+		public override bool RequiresFile { get { return false; } }
 
 		public override Image SmallIcon
 		{
-			get { return KeePass.Properties.Resources.B16x16_Imp_PassKeeper; }
+			get { return KeePass.Properties.Resources.B16x16_View_Detailed; }
 		}
 
 		public override void Import(PwDatabase pwStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
-			if(MessageService.AskYesNo(KPRes.ImportMustRead + MessageService.NewParagraph +
-				KPRes.ImportMustReadQuestion) == false)
+			if(!MessageService.AskYesNo(KPRes.ImportMustRead + MessageService.NewParagraph +
+				KPRes.ImportMustReadQuestion))
 			{
 				AppHelp.ShowHelp(AppDefs.HelpTopics.ImportExport,
 					AppDefs.HelpTopics.ImportExportPassKeeper);
