@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,11 +20,9 @@
 using System;
 using System.Collections.Generic;
 using System.Diagnostics;
-using System.Drawing;
 using System.IO;
 using System.Text;
 using System.Xml;
-using System.Xml.Serialization;
 
 using KeePass.Resources;
 
@@ -47,11 +45,6 @@ namespace KeePass.DataExchange.Formats
 
 		public override bool ImportAppendsToRootGroupOnly { get { return true; } }
 
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_HTML; }
-		}
-
 		private const string ElemRoot = "xml";
 		private const string ElemEntries = "entries";
 		private const string ElemEntry = "entry";
@@ -88,7 +81,7 @@ namespace KeePass.DataExchange.Formats
 			}
 
 			// Fix '>' characters, for version 1.0.5
-			nIndex = strDoc.IndexOf('>');
+			nIndex = strDoc.IndexOf('>', 3);
 			while(nIndex >= 0)
 			{
 				char chPrev = strDoc[nIndex - 1];
