@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,10 +19,9 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
-using System.Drawing;
-using System.IO;
 using System.Diagnostics;
+using System.IO;
+using System.Text;
 
 using KeePass.Resources;
 
@@ -42,11 +41,6 @@ namespace KeePass.DataExchange.Formats
 		public override string DefaultExtension { get { return "csv"; } }
 		public override string ApplicationGroup { get { return KPRes.PasswordManagers; } }
 
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_Imp_PwsPlus; }
-		}
-
 		public override void Import(PwDatabase pwStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
@@ -109,8 +103,7 @@ namespace KeePass.DataExchange.Formats
 						ImportUtil.AppendToField(pe, PwDefs.NotesField, strNotes, pwStorage);
 					else
 						pe.Strings.Set(PwDefs.NotesField, new ProtectedString(
-							((pwStorage == null) ? false :
-							pwStorage.MemoryProtection.ProtectNotes), strNotesPre +
+							pwStorage.MemoryProtection.ProtectNotes, strNotesPre +
 							Environment.NewLine + Environment.NewLine + strNotes));
 				}
 			}
