@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,15 +20,12 @@
 using System;
 using System.Collections.Generic;
 using System.Diagnostics;
-using System.Drawing;
 using System.IO;
 using System.Text;
 using System.Xml;
 using System.Xml.XPath;
 
 using KeePass.Resources;
-using KeePass.UI;
-using KeePass.Util;
 
 using KeePassLib;
 using KeePassLib.Interfaces;
@@ -39,7 +36,7 @@ namespace KeePass.DataExchange.Formats
 {
 	// KasperskyPwMgrXml50 derives from this
 
-	// 5.0.4.232-8.0.7.78+
+	// 5.0.4.232-8.4.4+
 	internal class StickyPwXml50 : FileFormatProvider
 	{
 		public override bool SupportsImport { get { return true; } }
@@ -49,13 +46,6 @@ namespace KeePass.DataExchange.Formats
 		public override string DefaultExtension { get { return "xml"; } }
 		public override string ApplicationGroup { get { return KPRes.PasswordManagers; } }
 
-		public override bool ImportAppendsToRootGroupOnly { get { return true; } }
-
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_Imp_StickyPw; }
-		}
-
 		public override void Import(PwDatabase pwStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
@@ -64,20 +54,78 @@ namespace KeePass.DataExchange.Formats
 				XPathDocument xpDoc = new XPathDocument(xr);
 				XPathNavigator xpNav = xpDoc.CreateNavigator();
 
-				ImportLogins(xpNav, pwStorage);
-				ImportMemos(xpNav, pwStorage);
+				Dictionary<string, PwGroup> dGroups = ImportGroups(xpNav, pwStorage);
+
+				ImportLogins(xpNav, dGroups, pwStorage);
+				ImportMemos(xpNav, dGroups, pwStorage);
 			}
 		}
 
-		private static void ImportLogins(XPathNavigator xpNav, PwDatabase pd)
+		private static Dictionary<string, PwGroup> ImportGroups(XPathNavigator xpNav,
+			PwDatabase pd)
+		{
+			List<PwGroup> l = new List<PwGroup>(); // Original order
+			Dictionary<string, PwGroup> d = new Dictionary<string, PwGroup>();
+			Dictionary<PwGroup, string> dParents = new Dictionary<PwGroup, string>();
+
+			XPathNodeIterator it = xpNav.Select(
+				"/root/Database/Groups/Group | /root/Database/SecureMemoGroups/Group");
+			while(it.MoveNext())
+			{
+				XPathNavigator xpGroup = it.Current;
+				PwGroup pg = new PwGroup(true, true);
+
+				string strName = xpGroup.GetAttribute("Name", string.Empty);
+				if(string.IsNullOrEmpty(strName)) { Debug.Assert(false); strName = KPRes.Group; }
+				pg.Name = strName;
+
+				string strID = xpGroup.GetAttribute("ID", string.Empty);
+				if(string.IsNullOrEmpty(strID)) { Debug.Assert(false); continue; }
+				Debug.Assert(!d.ContainsKey(strID));
+
+				string strParentID = xpGroup.GetAttribute("ParentID", string.Empty);
+
+				l.Add(pg);
+				d[strID] = pg;
+				if(!string.IsNullOrEmpty(strParentID)) dParents[pg] = strParentID;
+				else { Debug.Assert(false); }
+			}
+
+			foreach(PwGroup pg in l)
+			{
+				string strParentID;
+				if(dParents.TryGetValue(pg, out strParentID))
+				{
+					PwGroup pgParent;
+					if(d.TryGetValue(strParentID, out pgParent))
+					{
+						if((pgParent != pg) && !pgParent.IsContainedIn(pg))
+						{
+							pgParent.AddGroup(pg, true);
+							continue;
+						}
+						else { Debug.Assert(false); }
+					}
+					// else { Debug.Assert(false); } // May be negative ID
+				}
+				else { Debug.Assert(false); }
+
+				pd.RootGroup.AddGroup(pg, true);
+			}
+
+			d[string.Empty] = pd.RootGroup;
+			return d;
+		}
+
+		private static void ImportLogins(XPathNavigator xpNav,
+			Dictionary<string, PwGroup> dGroups, PwDatabase pd)
 		{
 			XPathNodeIterator it = xpNav.Select("/root/Database/Logins/Login");
 			while(it.MoveNext())
 			{
-				PwEntry pe = new PwEntry(true, true);
-				pd.RootGroup.AddEntry(pe, true);
-
 				XPathNavigator xpLogin = it.Current;
+				PwEntry pe = new PwEntry(true, true);
+
 				pe.Strings.Set(PwDefs.UserNameField, new ProtectedString(
 					pd.MemoryProtection.ProtectUserName,
 					xpLogin.GetAttribute("Name", string.Empty)));
@@ -85,14 +133,14 @@ namespace KeePass.DataExchange.Formats
 					pd.MemoryProtection.ProtectPassword,
 					xpLogin.GetAttribute("Password", string.Empty)));
 
-				SetTimes(pe, xpLogin);
+				ImportTimes(xpLogin, pe);
 
 				string strID = xpLogin.GetAttribute("ID", string.Empty);
-				if(string.IsNullOrEmpty(strID)) continue;
 
-				XPathNavigator xpAccLogin = xpNav.SelectSingleNode(
-					@"/root/Database/Accounts/Account/LoginLinks/Login[@SourceLoginID='" +
-					strID + @"']/../..");
+				XPathNavigator xpAccLogin = (!string.IsNullOrEmpty(strID) ?
+					xpNav.SelectSingleNode(
+					"/root/Database/Accounts/Account/LoginLinks/Login[@SourceLoginID='" +
+					strID + "']/../..") : null);
 				if(xpAccLogin == null) { Debug.Assert(false); }
 				else
 				{
@@ -110,26 +158,27 @@ namespace KeePass.DataExchange.Formats
 					pe.Strings.Set(PwDefs.NotesField, new ProtectedString(
 						pd.MemoryProtection.ProtectNotes, strNotes));
 				}
+
+				AddToParent(xpAccLogin, pe, dGroups);
 			}
 		}
 
-		private static void ImportMemos(XPathNavigator xpNav, PwDatabase pd)
+		private static void ImportMemos(XPathNavigator xpNav,
+			Dictionary<string, PwGroup> dGroups, PwDatabase pd)
 		{
 			XPathNodeIterator it = xpNav.Select("/root/Database/SecureMemos/SecureMemo");
 			while(it.MoveNext())
 			{
+				XPathNavigator xpMemo = it.Current;
 				PwEntry pe = new PwEntry(true, true);
-				pd.RootGroup.AddEntry(pe, true);
 
 				pe.IconId = PwIcon.PaperNew;
 
-				XPathNavigator xpMemo = it.Current;
-
 				pe.Strings.Set(PwDefs.TitleField, new ProtectedString(
 					pd.MemoryProtection.ProtectTitle,
 					xpMemo.GetAttribute("Name", string.Empty)));
 
-				SetTimes(pe, xpMemo);
+				ImportTimes(xpMemo, pe);
 
 				try
 				{
@@ -141,21 +190,62 @@ namespace KeePass.DataExchange.Formats
 						false, StrUtil.Utf8.GetBytes(strMemoRtf)));
 				}
 				catch(Exception) { Debug.Assert(false); }
+
+				AddToParent(xpMemo, pe, dGroups);
 			}
 		}
 
-		private static void SetTimes(PwEntry pe, XPathNavigator xpNode)
+		private static void AddToParent(XPathNavigator xpNav, PwEntry pe,
+			Dictionary<string, PwGroup> dGroups)
 		{
-			DateTime dt;
-			string strTime = (xpNode.GetAttribute("CreatedDate", string.Empty));
-			if(DateTime.TryParse(strTime, out dt))
-				pe.CreationTime = TimeUtil.ToUtc(dt, true);
+			if(xpNav != null)
+			{
+				string strParentID = xpNav.GetAttribute("ParentID", string.Empty);
+				if(!string.IsNullOrEmpty(strParentID))
+				{
+					PwGroup pgParent;
+					if(dGroups.TryGetValue(strParentID, out pgParent))
+					{
+						pgParent.AddEntry(pe, true);
+						return;
+					}
+				}
+				else { Debug.Assert(false); }
+			}
+
+			dGroups[string.Empty].AddEntry(pe, true);
+		}
+
+		private static DateTime? GetTime(XPathNavigator xpNav, string strAttrib)
+		{
+			try
+			{
+				string str = xpNav.GetAttribute(strAttrib, string.Empty);
+				if(!string.IsNullOrEmpty(str))
+					return TimeUtil.ToUtc(XmlConvert.ToDateTime(str,
+						XmlDateTimeSerializationMode.Local), false);
+			}
+			catch(Exception) { Debug.Assert(false); }
+
+			return null;
+		}
+
+		private static void ImportTimes(XPathNavigator xpNav, PwEntry pe)
+		{
+			DateTime? odt = GetTime(xpNav, "CreatedDate");
+			if(odt.HasValue) pe.CreationTime = odt.Value;
 			else { Debug.Assert(false); }
 
-			strTime = (xpNode.GetAttribute("ModifiedDate", string.Empty));
-			if(DateTime.TryParse(strTime, out dt))
-				pe.LastModificationTime = TimeUtil.ToUtc(dt, true);
+			odt = GetTime(xpNav, "ModifiedDate");
+			if(odt.HasValue) pe.LastModificationTime = odt.Value;
 			else { Debug.Assert(false); }
+
+			odt = GetTime(xpNav, "ExpirationDate");
+			if(odt.HasValue)
+			{
+				pe.Expires = true;
+				pe.ExpiryTime = odt.Value;
+			}
 		}
 	}
 }
