@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,11 +44,6 @@ namespace KeePass.DataExchange.Formats
 
 		public override bool ImportAppendsToRootGroupOnly { get { return true; } }
 
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_Imp_TrueKey; }
-		}
-
 		public override void Import(PwDatabase pwStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
@@ -187,8 +182,8 @@ namespace KeePass.DataExchange.Formats
 							break;
 
 						case "favorite":
-							if(StrUtil.StringToBoolEx(strValue).GetValueOrDefault(false))
-								pe.AddTag("Favorite");
+							if(StrUtil.StringToBool(strValue))
+								pe.AddTag(PwDefs.FavoriteTag);
 							break;
 
 						case "gender":
