@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -522,8 +522,8 @@ namespace KeePass.DataExchange
 	/// </summary>
 	public sealed class KdbManager : IDisposable
 	{
-		private const string DllFile32 = "KeePassLibC32.dll";
-		private const string DllFile64 = "KeePassLibC64.dll";
+		internal const string DllFile32 = "KeePassLibC32.dll";
+		internal const string DllFile64 = "KeePassLibC64.dll";
 
 		private static readonly bool m_bX64 = (IntPtr.Size == 8);
 
@@ -672,9 +672,9 @@ namespace KeePass.DataExchange
 			if(!m_bX64) // Only check 32-bit structures
 			{
 #if VPF_ALIGN
-				bool bAligned = true;
+				const bool bAligned = true;
 #else
-				bool bAligned = false;
+				const bool bAligned = false;
 #endif
 
 				// Static structure layout assertions
