@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,12 +21,10 @@ using System;
 using System.Collections.Generic;
 using System.Collections.ObjectModel;
 using System.Diagnostics;
-using System.IO;
 using System.Text;
 using System.Threading;
 using System.Windows.Forms;
 
-using KeePass.App;
 using KeePass.DataExchange;
 using KeePass.Forms;
 using KeePass.Native;
@@ -323,10 +321,7 @@ namespace KeePass.Ecas
 					Program.MainForm.UIBlockInteraction(false);
 				}
 			}
-			catch(Exception ex)
-			{
-				throw new Exception(strCmd + MessageService.NewParagraph + ex.Message);
-			}
+			catch(Exception ex) { throw new ExtendedException(strCmd, ex); }
 			finally
 			{
 				try { if(p != null) p.Dispose(); }
@@ -369,35 +364,24 @@ namespace KeePass.Ecas
 			IOConnectionInfo ioc = IOFromParameters(strPath, strIOUserName, strIOPassword);
 			if(ioc == null) return;
 
-			CompositeKey cmpKey = KeyFromParams(a, 3, 4, 5);
+			CompositeKey ck = KeyFromParams(a, 3, 4, 5, ioc);
 
-			Program.MainForm.OpenDatabase(ioc, cmpKey, ioc.IsLocalFile());
+			Program.MainForm.OpenDatabase(ioc, ck, ioc.IsLocalFile());
 		}
 
 		private static CompositeKey KeyFromParams(EcasAction a, int iPassword,
-			int iKeyFile, int iUserAccount)
+			int iKeyFile, int iUserAccount, IOConnectionInfo ioc)
 		{
 			string strPassword = EcasUtil.GetParamString(a.Parameters, iPassword, true);
 			string strKeyFile = EcasUtil.GetParamString(a.Parameters, iKeyFile, true);
 			bool bUserAccount = EcasUtil.GetParamBool(a.Parameters, iUserAccount);
 
-			CompositeKey cmpKey = null;
-			if(!string.IsNullOrEmpty(strPassword) || !string.IsNullOrEmpty(strKeyFile) ||
-				bUserAccount)
-			{
-				List<string> vArgs = new List<string>();
-				if(!string.IsNullOrEmpty(strPassword))
-					vArgs.Add("-" + AppDefs.CommandLineOptions.Password + ":" + strPassword);
-				if(!string.IsNullOrEmpty(strKeyFile))
-					vArgs.Add("-" + AppDefs.CommandLineOptions.KeyFile + ":" + strKeyFile);
-				if(bUserAccount)
-					vArgs.Add("-" + AppDefs.CommandLineOptions.UserAccount);
+			byte[] pbPasswordUtf8 = null;
+			if(!string.IsNullOrEmpty(strPassword))
+				pbPasswordUtf8 = StrUtil.Utf8.GetBytes(strPassword);
 
-				CommandLineArgs cmdArgs = new CommandLineArgs(vArgs.ToArray());
-				cmpKey = KeyUtil.KeyFromCommandLine(cmdArgs);
-			}
-
-			return cmpKey;
+			return KeyUtil.CreateKey(pbPasswordUtf8, strKeyFile, bUserAccount,
+				ioc, false, false);
 		}
 
 		private static void SaveDatabaseFile(EcasAction a, EcasContext ctx)
@@ -416,13 +400,12 @@ namespace KeePass.Ecas
 			IOConnectionInfo ioc = IOFromParameters(strPath, strIOUserName, strIOPassword);
 			if(ioc == null) return;
 
-			PwDatabase pd = Program.MainForm.ActiveDatabase;
+			MainForm mf = Program.MainForm;
+			PwDatabase pd = mf.ActiveDatabase;
 			if((pd == null) || !pd.IsOpen) return;
 
-			bool? b = ImportUtil.Synchronize(pd, Program.MainForm, ioc, false,
-				Program.MainForm);
-			Program.MainForm.UpdateUI(false, null, true, null, true, null, false);
-			if(b.HasValue) Program.MainForm.SetStatusEx(b.Value ? KPRes.SyncSuccess : KPRes.SyncFailed);
+			bool? ob = ImportUtil.Synchronize(pd, mf, ioc, false, mf);
+			mf.UpdateUISyncPost(ob);
 		}
 
 		private static IOConnectionInfo IOFromParameters(string strPath,
@@ -471,24 +454,22 @@ namespace KeePass.Ecas
 			else { Debug.Assert(false); }
 			if(mm == PwMergeMethod.None) mm = PwMergeMethod.CreateNewUuids;
 
-			CompositeKey cmpKey = KeyFromParams(a, 3, 4, 5);
-			if((cmpKey == null) && ff.RequiresKey)
+			CompositeKey ck = KeyFromParams(a, 3, 4, 5, ioc);
+			if((ck == null) && ff.RequiresKey)
 			{
-				KeyPromptForm kpf = new KeyPromptForm();
-				kpf.InitEx(ioc, false, true);
+				KeyPromptFormResult r;
+				DialogResult dr = KeyPromptForm.ShowDialog(ioc, false, null, out r);
+				if((dr != DialogResult.OK) || (r == null)) return;
 
-				if(UIUtil.ShowDialogNotValue(kpf, DialogResult.OK)) return;
-
-				cmpKey = kpf.CompositeKey;
-				UIUtil.DestroyForm(kpf);
+				ck = r.CompositeKey;
 			}
 
-			bool? b = true;
-			try { b = ImportUtil.Import(pd, ff, ioc, mm, cmpKey); }
+			bool? ob = false; // Exception => UI update
+			try { ob = ImportUtil.Import(pd, ff, ioc, mm, ck); }
 			finally
 			{
-				if(b.GetValueOrDefault(false))
-					Program.MainForm.UpdateUI(false, null, true, null, true, null, true);
+				if(ob.HasValue)
+					Program.MainForm.UpdateUI(false, null, true, null, true, null, false);
 			}
 		}
 
@@ -513,6 +494,7 @@ namespace KeePass.Ecas
 				pg = (pgSub ?? (new PwGroup(true, true, KPRes.Group, PwIcon.Folder)));
 			}
 
+			strTag = StrUtil.NormalizeTag(strTag);
 			if(!string.IsNullOrEmpty(strTag))
 			{
 				pg = pg.CloneDeep();
@@ -523,7 +505,8 @@ namespace KeePass.Ecas
 					long n = (long)l.UCount;
 					for(long i = n - 1; i >= 0; --i)
 					{
-						if(!l.GetAt((uint)i).HasTag(strTag))
+						List<string> lTags = l.GetAt((uint)i).GetTagsInherited();
+						if(!lTags.Contains(strTag))
 							l.RemoveAt((uint)i);
 					}
 
