@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,18 +19,14 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
-using System.IO;
-using System.Net.NetworkInformation;
-using System.Windows.Forms;
 using System.Diagnostics;
+using System.Net.NetworkInformation;
+using System.Text;
 
 using KeePass.Resources;
-using KeePass.UI;
 
 using KeePassLib;
 using KeePassLib.Serialization;
-using KeePassLib.Utility;
 
 namespace KeePass.Ecas
 {
