@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ namespace KeePass.Ecas
 {
 	public sealed class EcasEnum
 	{
-		private EcasEnumItem[] m_vItems;
+		private readonly EcasEnumItem[] m_vItems;
 		public EcasEnumItem[] Items
 		{
 			get { return m_vItems; }
@@ -78,13 +78,13 @@ namespace KeePass.Ecas
 
 	public sealed class EcasEnumItem
 	{
-		private uint m_id;
+		private readonly uint m_id;
 		public uint ID
 		{
 			get { return m_id; }
 		}
 
-		private string m_name;
+		private readonly string m_name;
 		public string Name
 		{
 			get { return m_name; }
