@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,18 +21,15 @@ using System;
 using System.Collections.Generic;
 using System.Text;
 
+using KeePassLib.Utility;
+
 namespace KeePass.Ecas
 {
 	public sealed class EcasParameter
 	{
-		private static EcasParameter[] m_epvNone = null;
 		public static EcasParameter[] EmptyArray
 		{
-			get
-			{
-				if(m_epvNone == null) m_epvNone = new EcasParameter[0];
-				return m_epvNone;
-			}
+			get { return MemUtil.EmptyArray<EcasParameter>(); }
 		}
 
 		private string m_strName;
