@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ namespace KeePass.Ecas
 
 	public sealed class EcasPropertyDictionary
 	{
-		private Dictionary<string, object> m_dict = new Dictionary<string, object>();
+		private readonly Dictionary<string, object> m_dict = new Dictionary<string, object>();
 
 		public EcasPropertyDictionary()
 		{
