@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,9 +38,6 @@ using KeePassLib.Utility;
 
 namespace KeePass.Forms
 {
-	public delegate void AceColumnDelegate(AceColumn c);
-	// public delegate void UpdateUIDelegate(bool bGuiToInternal);
-
 	public partial class ColumnsForm : Form
 	{
 		private bool m_bIgnoreHideCheckEvent = false;
@@ -48,7 +45,7 @@ namespace KeePass.Forms
 		public ColumnsForm()
 		{
 			InitializeComponent();
-			Program.Translation.ApplyTo(this);
+			GlobalWindowManager.InitializeForm(this);
 		}
 
 		private void OnFormLoad(object sender, EventArgs e)
@@ -61,25 +58,30 @@ namespace KeePass.Forms
 			this.Icon = AppIcons.Default;
 			this.Text = KPRes.ConfigureColumns;
 
+			UIUtil.SetExplorerTheme(m_lvColumns, false);
+
 			float fWidth = (float)(m_lvColumns.ClientRectangle.Width -
 				UIUtil.GetVScrollBarWidth()) / 5.0f;
 			m_lvColumns.Columns.Add(KPRes.Column, (int)(fWidth * 3.0f));
 			m_lvColumns.Columns.Add(KPRes.Asterisks + " ***", (int)fWidth);
 			m_lvColumns.Columns.Add(KPRes.Toggle + " ***", (int)fWidth);
 
-			UIUtil.SetExplorerTheme(m_lvColumns, false);
-
 			UpdateColumnPropInfo();
-
 			ThreadPool.QueueUserWorkItem(new WaitCallback(FillColumnsList));
+
+			Debug.Assert(KPRes.RememberHidingPasswordsMain.StartsWith(
+				StrUtil.RemoveAccelerator(m_cbRmbHidingPasswords.Text)));
+			m_cbRmbHidingPasswords.Checked = Program.Config.UI.Hiding.RememberHidingPasswordsMain;
 		}
 
 		private void AddAceColumnTh(AceColumn c)
 		{
 			string strLvgName = KPRes.StandardFields;
-			if(c.Type == AceColumnType.CustomString) strLvgName = KPRes.CustomFields;
-			else if(c.Type == AceColumnType.PluginExt) strLvgName = KPRes.PluginProvided;
-			else if((int)c.Type > (int)AceColumnType.PluginExt)
+			if(c.Type == AceColumnType.CustomString)
+				strLvgName = KPRes.CustomFields;
+			else if(c.Type == AceColumnType.PluginExt)
+				strLvgName = KPRes.PluginProvided;
+			else if((c.Type == AceColumnType.Size) || (c.Type == AceColumnType.LastPasswordModTime))
 				strLvgName = KPRes.More;
 
 			ListViewGroup lvgContainer = null;
@@ -99,9 +101,9 @@ namespace KeePass.Forms
 			lvi.SubItems.Add(c.HideWithAsterisks ? KPRes.Yes : KPRes.No);
 
 			if(c.Type == AceColumnType.Password)
-				lvi.SubItems.Add(KPRes.KeyboardKeyCtrl + "+H");
+				lvi.SubItems.Add(UIUtil.GetKeysName(Keys.Control | Keys.H));
 			else if(c.Type == AceColumnType.UserName)
-				lvi.SubItems.Add(KPRes.KeyboardKeyCtrl + "+J");
+				lvi.SubItems.Add(UIUtil.GetKeysName(Keys.Control | Keys.J));
 			else lvi.SubItems.Add(string.Empty);
 
 			bool bChecked = false;
@@ -137,7 +139,7 @@ namespace KeePass.Forms
 
 		private void AddAceColumn(List<AceColumn> lContainer, AceColumn c)
 		{
-			m_lvColumns.Invoke(new AceColumnDelegate(AddAceColumnTh), c);
+			m_lvColumns.Invoke(new GAction<AceColumn>(AddAceColumnTh), c);
 			lContainer.Add(c);
 		}
 
@@ -168,15 +170,27 @@ namespace KeePass.Forms
 			AddStdAceColumn(l, AceColumnType.Password);
 			AddStdAceColumn(l, AceColumnType.Url);
 			AddStdAceColumn(l, AceColumnType.Notes);
+			AddStdAceColumn(l, AceColumnType.ExpiryTime);
+			AddStdAceColumn(l, AceColumnType.ExpiryTimeDateOnly);
+
+			AddStdAceColumn(l, AceColumnType.Attachment);
+			AddStdAceColumn(l, AceColumnType.AttachmentCount);
+
+			AddStdAceColumn(l, AceColumnType.Tags);
+			AddStdAceColumn(l, AceColumnType.OverrideUrl);
+			AddStdAceColumn(l, AceColumnType.Uuid);
+
+			AddStdAceColumn(l, AceColumnType.AutoTypeEnabled);
+			AddStdAceColumn(l, AceColumnType.AutoTypeSequences);
+
 			AddStdAceColumn(l, AceColumnType.CreationTime);
-			
+			AddStdAceColumn(l, AceColumnType.LastModificationTime);
 			if((Program.Config.UI.UIFlags & (ulong)AceUIFlags.ShowLastAccessTime) != 0)
 				AddStdAceColumn(l, AceColumnType.LastAccessTime);
+			AddStdAceColumn(l, AceColumnType.HistoryCount);
 
-			AddStdAceColumn(l, AceColumnType.LastModificationTime);
-			AddStdAceColumn(l, AceColumnType.ExpiryTime);
-			AddStdAceColumn(l, AceColumnType.Uuid);
-			AddStdAceColumn(l, AceColumnType.Attachment);
+			AddStdAceColumn(l, AceColumnType.Size);
+			AddStdAceColumn(l, AceColumnType.LastPasswordModTime);
 
 			SortedDictionary<string, AceColumn> d =
 				new SortedDictionary<string, AceColumn>(StrUtil.CaseIgnoreComparer);
@@ -218,14 +232,6 @@ namespace KeePass.Forms
 				AddAceColumn(l, kvpCustom.Value);
 			}
 
-			AddStdAceColumn(l, AceColumnType.Size);
-			AddStdAceColumn(l, AceColumnType.AttachmentCount);
-			AddStdAceColumn(l, AceColumnType.HistoryCount);
-			AddStdAceColumn(l, AceColumnType.OverrideUrl);
-			AddStdAceColumn(l, AceColumnType.Tags);
-			AddStdAceColumn(l, AceColumnType.ExpiryTimeDateOnly);
-			AddStdAceColumn(l, AceColumnType.LastPasswordModTime);
-
 			d.Clear();
 			// Add active plugin columns (including those of uninstalled plugins)
 			foreach(AceColumn cCur in lCur)
@@ -321,6 +327,8 @@ namespace KeePass.Forms
 
 			mw.EntryListColumnDisplayOrder = ComputeNewDisplayOrder(l,
 				lOld, mw.EntryListColumnDisplayOrder);
+
+			Program.Config.UI.Hiding.RememberHidingPasswordsMain = m_cbRmbHidingPasswords.Checked;
 		}
 
 		private void OnBtnCancel(object sender, EventArgs e)
