@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -97,7 +97,7 @@ namespace KeePass.Forms
 		public CsvImportForm()
 		{
 			InitializeComponent();
-			Program.Translation.ApplyTo(this);
+			GlobalWindowManager.InitializeForm(this);
 		}
 
 		private void OnFormLoad(object sender, EventArgs e)
@@ -164,6 +164,9 @@ namespace KeePass.Forms
 
 			m_cmbFieldFormat.Text = string.Empty;
 
+			AccessibilityEx.SetName(m_btnFieldMoveUp, KPRes.MoveUp);
+			AccessibilityEx.SetName(m_btnFieldMoveDown, KPRes.MoveDown);
+
 			m_bInitializing = false;
 
 			UpdateTextPreview();
@@ -172,8 +175,6 @@ namespace KeePass.Forms
 
 			ProcessResize();
 			EnableControlsEx();
-
-			UIUtil.SetFocus(m_btnTabNext, this);
 		}
 
 		private void OnFormClosed(object sender, FormClosedEventArgs e)
@@ -237,7 +238,7 @@ namespace KeePass.Forms
 					};
 				else if(t == CsvFieldType.Group)
 					vItems = new string[] { string.Empty, ".", "/", "\\" };
-				else vItems = new string[0];
+				else vItems = MemUtil.EmptyArray<string>();
 
 				foreach(string strPre in vItems)
 					m_cmbFieldFormat.Items.Add(strPre);
@@ -260,6 +261,8 @@ namespace KeePass.Forms
 		private string GetDecodedText()
 		{
 			StrEncodingInfo sei = StrUtil.GetEncoding(m_cmbEnc.Text);
+			if(sei == null) { Debug.Assert(false); return string.Empty; }
+
 			try
 			{
 				string str = (sei.Encoding.GetString(m_pbData, (int)m_uStartOffset,
@@ -448,7 +451,7 @@ namespace KeePass.Forms
 		{
 			CsvFieldType t = GetCsvFieldType();
 
-			string strUrl = null;
+			string strUrl;
 			if(IsTimeField(t))
 				strUrl = "https://msdn.microsoft.com/en-us/library/8kb3ddd4.aspx";
 			// else if(t == CsvFieldType.Group)
@@ -611,11 +614,7 @@ namespace KeePass.Forms
 						pe.Expires = (bParseSuccess && (pe.ExpiryTime != dtNoExpire));
 					}
 					else if(cfi.Type == CsvFieldType.Tags)
-					{
-						List<string> lTags = StrUtil.StringToTags(strField);
-						foreach(string strTag in lTags)
-							pe.AddTag(strTag);
-					}
+						StrUtil.AddTags(pe.Tags, StrUtil.StringToTags(strField));
 					else { Debug.Assert(false); }
 
 					if(bCreatePreview)
