@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@ using System.Text;
 using System.Windows.Forms;
 
 using KeePass.App;
+using KeePass.App.Configuration;
 using KeePass.Resources;
 using KeePass.UI;
 
@@ -37,63 +38,16 @@ namespace KeePass.Forms
 {
 	public partial class DuplicationForm : Form
 	{
-		// Copy data from controls to simple member variables,
-		// because ApplyTo must work after the dialog has been destroyed.
-
-		private bool m_bAppendCopy = true;
-		// public bool AppendCopyToTitles
-		// {
-		//	get { return m_bAppendCopy; }
-		// }
-
+		// Copy data from controls to simple member variables, because
+		// ApplyTo must work after the dialog has been destroyed.
+		private bool m_bExtendTitle = true;
 		private bool m_bFieldRefs = false;
-		// public bool ReplaceDataByFieldRefs
-		// {
-		//	get { return m_bFieldRefs; }
-		// }
-		
 		private bool m_bCopyHistory = true;
-		// public bool CopyHistory
-		// {
-		//	get { return m_bCopyHistory; }
-		// }
-
-		public void ApplyTo(PwEntry peNew, PwEntry pe, PwDatabase pd)
-		{
-			if((peNew == null) || (pe == null)) { Debug.Assert(false); return; }
-
-			Debug.Assert(peNew.Strings.ReadSafe(PwDefs.UserNameField) ==
-				pe.Strings.ReadSafe(PwDefs.UserNameField));
-			Debug.Assert(peNew.Strings.ReadSafe(PwDefs.PasswordField) ==
-				pe.Strings.ReadSafe(PwDefs.PasswordField));
-
-			if(m_bAppendCopy && (pd != null))
-			{
-				string strTitle = peNew.Strings.ReadSafe(PwDefs.TitleField);
-				peNew.Strings.Set(PwDefs.TitleField, new ProtectedString(
-					pd.MemoryProtection.ProtectTitle, strTitle + " - " +
-					KPRes.CopyOfItem));
-			}
-
-			if(m_bFieldRefs && (pd != null))
-			{
-				string strUser = @"{REF:U@I:" + pe.Uuid.ToHexString() + @"}";
-				peNew.Strings.Set(PwDefs.UserNameField, new ProtectedString(
-					pd.MemoryProtection.ProtectUserName, strUser));
-
-				string strPw = @"{REF:P@I:" + pe.Uuid.ToHexString() + @"}";
-				peNew.Strings.Set(PwDefs.PasswordField, new ProtectedString(
-					pd.MemoryProtection.ProtectPassword, strPw));
-			}
-
-			if(!m_bCopyHistory)
-				peNew.History = new PwObjectList<PwEntry>();
-		}
 
 		public DuplicationForm()
 		{
 			InitializeComponent();
-			Program.Translation.ApplyTo(this);
+			GlobalWindowManager.InitializeForm(this);
 		}
 
 		private void OnFormLoad(object sender, EventArgs e)
@@ -106,9 +60,13 @@ namespace KeePass.Forms
 			FontUtil.AssignDefaultBold(m_cbFieldRefs);
 			FontUtil.AssignDefaultBold(m_cbCopyHistory);
 
-			m_cbAppendCopy.Checked = m_bAppendCopy;
-			m_cbFieldRefs.Checked = m_bFieldRefs;
-			m_cbCopyHistory.Checked = m_bCopyHistory;
+			FormDataExchange fdx = new FormDataExchange(this, true, true, true);
+			AceDuplication aceDup = Program.Config.Defaults.Duplication;
+			fdx.Add(m_cbAppendCopy, aceDup, "ExtendTitle");
+			fdx.Add(m_cbFieldRefs, aceDup, "CreateFieldReferences");
+			fdx.Add(m_cbCopyHistory, aceDup, "CopyHistory");
+
+			UIUtil.SetEnabledFast(m_cbFieldRefs.Enabled, m_lblFieldRefs, m_lnkFieldRefs);
 		}
 
 		private void OnFormClosed(object sender, FormClosedEventArgs e)
@@ -123,9 +81,42 @@ namespace KeePass.Forms
 
 		private void OnBtnOK(object sender, EventArgs e)
 		{
-			m_bAppendCopy = m_cbAppendCopy.Checked;
+			m_bExtendTitle = m_cbAppendCopy.Checked;
 			m_bFieldRefs = m_cbFieldRefs.Checked;
 			m_bCopyHistory = m_cbCopyHistory.Checked;
 		}
+
+		public void ApplyTo(PwEntry peNew, PwEntry pe, PwDatabase pd)
+		{
+			if((peNew == null) || (pe == null)) { Debug.Assert(false); return; }
+			Debug.Assert(this.IsDisposed);
+
+			Debug.Assert(peNew.Strings.ReadSafe(PwDefs.UserNameField) ==
+				pe.Strings.ReadSafe(PwDefs.UserNameField));
+			Debug.Assert(peNew.Strings.ReadSafe(PwDefs.PasswordField) ==
+				pe.Strings.ReadSafe(PwDefs.PasswordField));
+
+			if(m_bExtendTitle && (pd != null))
+			{
+				string strTitle = peNew.Strings.ReadSafe(PwDefs.TitleField);
+				peNew.Strings.Set(PwDefs.TitleField, new ProtectedString(
+					pd.MemoryProtection.ProtectTitle, strTitle + " - " +
+					KPRes.CopyOfItem));
+			}
+
+			if(m_bFieldRefs && (pd != null))
+			{
+				string strUser = "{REF:U@I:" + pe.Uuid.ToHexString() + "}";
+				peNew.Strings.Set(PwDefs.UserNameField, new ProtectedString(
+					pd.MemoryProtection.ProtectUserName, strUser));
+
+				string strPw = "{REF:P@I:" + pe.Uuid.ToHexString() + "}";
+				peNew.Strings.Set(PwDefs.PasswordField, new ProtectedString(
+					pd.MemoryProtection.ProtectPassword, strPw));
+			}
+
+			if(!m_bCopyHistory)
+				peNew.History = new PwObjectList<PwEntry>();
+		}
 	}
 }
