@@ -28,19 +28,22 @@
 		/// </summary>
 		private void InitializeComponent()
 		{
+			this.components = new System.ComponentModel.Container();
 			System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(EditStringForm));
 			this.m_bannerImage = new System.Windows.Forms.PictureBox();
 			this.m_lblStringValueDesc = new System.Windows.Forms.Label();
 			this.m_lblStringIdDesc = new System.Windows.Forms.Label();
 			this.m_lblIDIntro = new System.Windows.Forms.Label();
-			this.m_richStringValue = new KeePass.UI.CustomRichTextBoxEx();
+			this.m_rtbValue = new KeePass.UI.CustomRichTextBoxEx();
 			this.m_lblSeparator = new System.Windows.Forms.Label();
 			this.m_btnOK = new System.Windows.Forms.Button();
 			this.m_btnCancel = new System.Windows.Forms.Button();
 			this.m_btnHelp = new System.Windows.Forms.Button();
 			this.m_cbProtect = new System.Windows.Forms.CheckBox();
 			this.m_lblValidationInfo = new System.Windows.Forms.Label();
-			this.m_cmbStringName = new System.Windows.Forms.ComboBox();
+			this.m_cmbName = new System.Windows.Forms.ComboBox();
+			this.m_btnGenPw = new System.Windows.Forms.Button();
+			this.m_ttRect = new System.Windows.Forms.ToolTip(this.components);
 			((System.ComponentModel.ISupportInitialize)(this.m_bannerImage)).BeginInit();
 			this.SuspendLayout();
 			// 
@@ -59,7 +62,7 @@
 			this.m_lblStringValueDesc.Location = new System.Drawing.Point(12, 156);
 			this.m_lblStringValueDesc.Name = "m_lblStringValueDesc";
 			this.m_lblStringValueDesc.Size = new System.Drawing.Size(37, 13);
-			this.m_lblStringValueDesc.TabIndex = 3;
+			this.m_lblStringValueDesc.TabIndex = 4;
 			this.m_lblStringValueDesc.Text = "&Value:";
 			// 
 			// m_lblStringIdDesc
@@ -68,7 +71,7 @@
 			this.m_lblStringIdDesc.Location = new System.Drawing.Point(12, 116);
 			this.m_lblStringIdDesc.Name = "m_lblStringIdDesc";
 			this.m_lblStringIdDesc.Size = new System.Drawing.Size(38, 13);
-			this.m_lblStringIdDesc.TabIndex = 0;
+			this.m_lblStringIdDesc.TabIndex = 1;
 			this.m_lblStringIdDesc.Text = "&Name:";
 			// 
 			// m_lblIDIntro
@@ -76,17 +79,17 @@
 			this.m_lblIDIntro.Location = new System.Drawing.Point(12, 67);
 			this.m_lblIDIntro.Name = "m_lblIDIntro";
 			this.m_lblIDIntro.Size = new System.Drawing.Size(385, 40);
-			this.m_lblIDIntro.TabIndex = 10;
+			this.m_lblIDIntro.TabIndex = 0;
 			this.m_lblIDIntro.Text = resources.GetString("m_lblIDIntro.Text");
 			// 
-			// m_richStringValue
+			// m_rtbValue
 			// 
-			this.m_richStringValue.Location = new System.Drawing.Point(56, 154);
-			this.m_richStringValue.Name = "m_richStringValue";
-			this.m_richStringValue.ScrollBars = System.Windows.Forms.RichTextBoxScrollBars.Vertical;
-			this.m_richStringValue.Size = new System.Drawing.Size(341, 78);
-			this.m_richStringValue.TabIndex = 4;
-			this.m_richStringValue.Text = "";
+			this.m_rtbValue.Location = new System.Drawing.Point(56, 154);
+			this.m_rtbValue.Name = "m_rtbValue";
+			this.m_rtbValue.ScrollBars = System.Windows.Forms.RichTextBoxScrollBars.Vertical;
+			this.m_rtbValue.Size = new System.Drawing.Size(341, 78);
+			this.m_rtbValue.TabIndex = 5;
+			this.m_rtbValue.Text = "";
 			// 
 			// m_lblSeparator
 			// 
@@ -102,7 +105,7 @@
 			this.m_btnOK.Location = new System.Drawing.Point(241, 282);
 			this.m_btnOK.Name = "m_btnOK";
 			this.m_btnOK.Size = new System.Drawing.Size(75, 23);
-			this.m_btnOK.TabIndex = 6;
+			this.m_btnOK.TabIndex = 10;
 			this.m_btnOK.Text = "OK";
 			this.m_btnOK.UseVisualStyleBackColor = true;
 			this.m_btnOK.Click += new System.EventHandler(this.OnBtnOK);
@@ -113,7 +116,7 @@
 			this.m_btnCancel.Location = new System.Drawing.Point(322, 282);
 			this.m_btnCancel.Name = "m_btnCancel";
 			this.m_btnCancel.Size = new System.Drawing.Size(75, 23);
-			this.m_btnCancel.TabIndex = 7;
+			this.m_btnCancel.TabIndex = 11;
 			this.m_btnCancel.Text = "Cancel";
 			this.m_btnCancel.UseVisualStyleBackColor = true;
 			this.m_btnCancel.Click += new System.EventHandler(this.OnBtnCancel);
@@ -131,10 +134,10 @@
 			// m_cbProtect
 			// 
 			this.m_cbProtect.AutoSize = true;
-			this.m_cbProtect.Location = new System.Drawing.Point(56, 238);
+			this.m_cbProtect.Location = new System.Drawing.Point(56, 242);
 			this.m_cbProtect.Name = "m_cbProtect";
 			this.m_cbProtect.Size = new System.Drawing.Size(179, 17);
-			this.m_cbProtect.TabIndex = 5;
+			this.m_cbProtect.TabIndex = 6;
 			this.m_cbProtect.Text = "&Protect value in process memory";
 			this.m_cbProtect.UseVisualStyleBackColor = true;
 			// 
@@ -144,17 +147,25 @@
 			this.m_lblValidationInfo.Location = new System.Drawing.Point(53, 137);
 			this.m_lblValidationInfo.Name = "m_lblValidationInfo";
 			this.m_lblValidationInfo.Size = new System.Drawing.Size(344, 14);
-			this.m_lblValidationInfo.TabIndex = 2;
+			this.m_lblValidationInfo.TabIndex = 3;
 			this.m_lblValidationInfo.Text = "<>";
 			// 
-			// m_cmbStringName
+			// m_cmbName
 			// 
-			this.m_cmbStringName.FormattingEnabled = true;
-			this.m_cmbStringName.Location = new System.Drawing.Point(56, 113);
-			this.m_cmbStringName.Name = "m_cmbStringName";
-			this.m_cmbStringName.Size = new System.Drawing.Size(341, 21);
-			this.m_cmbStringName.TabIndex = 1;
-			this.m_cmbStringName.TextChanged += new System.EventHandler(this.OnNameTextChanged);
+			this.m_cmbName.FormattingEnabled = true;
+			this.m_cmbName.Location = new System.Drawing.Point(56, 113);
+			this.m_cmbName.Name = "m_cmbName";
+			this.m_cmbName.Size = new System.Drawing.Size(341, 21);
+			this.m_cmbName.TabIndex = 2;
+			this.m_cmbName.TextChanged += new System.EventHandler(this.OnNameTextChanged);
+			// 
+			// m_btnGenPw
+			// 
+			this.m_btnGenPw.Location = new System.Drawing.Point(365, 238);
+			this.m_btnGenPw.Name = "m_btnGenPw";
+			this.m_btnGenPw.Size = new System.Drawing.Size(32, 23);
+			this.m_btnGenPw.TabIndex = 7;
+			this.m_btnGenPw.UseVisualStyleBackColor = true;
 			// 
 			// EditStringForm
 			// 
@@ -163,14 +174,15 @@
 			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
 			this.CancelButton = this.m_btnCancel;
 			this.ClientSize = new System.Drawing.Size(409, 317);
-			this.Controls.Add(this.m_cmbStringName);
+			this.Controls.Add(this.m_btnGenPw);
+			this.Controls.Add(this.m_cmbName);
 			this.Controls.Add(this.m_lblValidationInfo);
 			this.Controls.Add(this.m_cbProtect);
 			this.Controls.Add(this.m_btnHelp);
 			this.Controls.Add(this.m_btnCancel);
 			this.Controls.Add(this.m_btnOK);
 			this.Controls.Add(this.m_lblSeparator);
-			this.Controls.Add(this.m_richStringValue);
+			this.Controls.Add(this.m_rtbValue);
 			this.Controls.Add(this.m_lblIDIntro);
 			this.Controls.Add(this.m_lblStringIdDesc);
 			this.Controls.Add(this.m_lblStringValueDesc);
@@ -184,7 +196,6 @@
 			this.Text = "Edit Entry String";
 			this.Load += new System.EventHandler(this.OnFormLoad);
 			this.FormClosed += new System.Windows.Forms.FormClosedEventHandler(this.OnFormClosed);
-			this.FormClosing += new System.Windows.Forms.FormClosingEventHandler(this.OnFormClosing);
 			((System.ComponentModel.ISupportInitialize)(this.m_bannerImage)).EndInit();
 			this.ResumeLayout(false);
 			this.PerformLayout();
@@ -197,13 +208,15 @@
 		private System.Windows.Forms.Label m_lblStringValueDesc;
 		private System.Windows.Forms.Label m_lblStringIdDesc;
 		private System.Windows.Forms.Label m_lblIDIntro;
-		private KeePass.UI.CustomRichTextBoxEx m_richStringValue;
+		private KeePass.UI.CustomRichTextBoxEx m_rtbValue;
 		private System.Windows.Forms.Label m_lblSeparator;
 		private System.Windows.Forms.Button m_btnOK;
 		private System.Windows.Forms.Button m_btnCancel;
 		private System.Windows.Forms.Button m_btnHelp;
 		private System.Windows.Forms.CheckBox m_cbProtect;
 		private System.Windows.Forms.Label m_lblValidationInfo;
-		private System.Windows.Forms.ComboBox m_cmbStringName;
+		private System.Windows.Forms.ComboBox m_cmbName;
+		private System.Windows.Forms.Button m_btnGenPw;
+		private System.Windows.Forms.ToolTip m_ttRect;
 	}
 }
\ No newline at end of file
