@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ namespace KeePass.Forms
 		private ImageList m_ilIcons = null;
 		private string m_strDefaultRef = string.Empty;
 
-		private List<KeyValuePair<string, string>> m_vColumns =
+		private readonly List<KeyValuePair<string, string>> m_lColumns =
 			new List<KeyValuePair<string, string>>();
 
 		private string m_strResultRef = string.Empty;
@@ -61,7 +61,7 @@ namespace KeePass.Forms
 		public FieldRefForm()
 		{
 			InitializeComponent();
-			Program.Translation.ApplyTo(this);
+			GlobalWindowManager.InitializeForm(this);
 		}
 
 		private void OnFormLoad(object sender, EventArgs e)
@@ -75,13 +75,13 @@ namespace KeePass.Forms
 
 			UIUtil.SetExplorerTheme(m_lvEntries, true);
 
-			m_vColumns.Add(new KeyValuePair<string, string>(PwDefs.TitleField, KPRes.Title));
-			m_vColumns.Add(new KeyValuePair<string, string>(PwDefs.UserNameField, KPRes.UserName));
-			m_vColumns.Add(new KeyValuePair<string, string>(PwDefs.UrlField, KPRes.Url));
-			m_vColumns.Add(new KeyValuePair<string, string>(PwDefs.NotesField, KPRes.Notes));
+			m_lColumns.Add(new KeyValuePair<string, string>(PwDefs.TitleField, KPRes.Title));
+			m_lColumns.Add(new KeyValuePair<string, string>(PwDefs.UserNameField, KPRes.UserName));
+			m_lColumns.Add(new KeyValuePair<string, string>(PwDefs.UrlField, KPRes.Url));
+			m_lColumns.Add(new KeyValuePair<string, string>(PwDefs.NotesField, KPRes.Notes));
 
 			PwObjectList<PwEntry> vEntries = m_pgEntrySource.GetEntries(true);
-			UIUtil.CreateEntryList(m_lvEntries, vEntries, m_vColumns, m_ilIcons);
+			UIUtil.CreateEntryList(m_lvEntries, vEntries, m_lColumns, m_ilIcons);
 
 			m_radioIdUuid.Checked = true;
 
@@ -98,14 +98,10 @@ namespace KeePass.Forms
 			else m_radioRefPassword.Checked = true;
 		}
 
-		private void CleanUpEx()
-		{
-			m_lvEntries.SmallImageList = null; // Detach event handlers
-		}
-
 		private void OnFormClosed(object sender, FormClosedEventArgs e)
 		{
-			CleanUpEx();
+			m_lvEntries.SmallImageList = null; // Detach event handlers
+
 			GlobalWindowManager.RemoveWindow(this);
 		}
 
@@ -241,7 +237,7 @@ namespace KeePass.Forms
 				PwObjectList<PwEntry> lResults = new PwObjectList<PwEntry>();
 				m_pgEntrySource.SearchEntries(sp, lResults);
 
-				UIUtil.CreateEntryList(m_lvEntries, lResults, m_vColumns, m_ilIcons);
+				UIUtil.CreateEntryList(m_lvEntries, lResults, m_lColumns, m_ilIcons);
 			}
 		}
 
