@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ namespace KeePass.Forms
 		public UrlOverrideForm()
 		{
 			InitializeComponent();
-			Program.Translation.ApplyTo(this);
+			GlobalWindowManager.InitializeForm(this);
 		}
 
 		private void OnFormLoad(object sender, EventArgs e)
@@ -57,8 +57,6 @@ namespace KeePass.Forms
 
 			m_tbScheme.Text = m_ovr.Scheme;
 			m_tbOverride.Text = m_ovr.UrlOverride;
-
-			UIUtil.SetFocus(m_tbScheme, this);
 		}
 
 		private void OnFormClosed(object sender, FormClosedEventArgs e)
