@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -18,18 +18,21 @@
 */
 
 using System;
-using System.Diagnostics;
 using System.Runtime.InteropServices;
-using System.Security;
 using System.Text;
-using System.Windows.Forms;
 
 namespace KeePass.Native
 {
 	internal static partial class NativeMethods
 	{
+		private static readonly IntPtr FALSE_PTR = IntPtr.Zero;
+		private static readonly IntPtr TRUE_PTR = new IntPtr(1);
+
 		internal const int WM_SETFOCUS = 0x0007;
 		internal const int WM_KILLFOCUS = 0x0008;
+		private const int WM_SETREDRAW = 0x000B;
+		internal const int WM_SETTINGCHANGE = 0x001A;
+		internal const int WM_WINDOWPOSCHANGING = 0x0046;
 		internal const int WM_CONTEXTMENU = 0x007B;
 		internal const int WM_KEYDOWN = 0x0100;
 		internal const int WM_KEYUP = 0x0101;
@@ -115,9 +118,12 @@ namespace KeePass.Native
 		internal const int WS_VISIBLE = 0x10000000;
 
 		// internal const int WS_EX_COMPOSITED = 0x02000000;
+		internal const int WS_EX_TOPMOST = 0x00000008;
 
 		internal const int SW_SHOW = 5;
 
+		internal const uint SWP_SHOWWINDOW = 0x0040;
+
 		internal const int GCLP_HICON = -14;
 		internal const int GCLP_HICONSM = -34;
 
@@ -125,8 +131,13 @@ namespace KeePass.Native
 		internal const int ICON_BIG = 1;
 		internal const int ICON_SMALL2 = 2;
 
+		internal const int ECM_FIRST = 0x1500;
+		internal const int EM_SETCUEBANNER = ECM_FIRST + 1;
+
 		internal const int EM_GETCHARFORMAT = WM_USER + 58;
 		internal const int EM_SETCHARFORMAT = WM_USER + 68;
+		private const int EM_GETSCROLLPOS = WM_USER + 221;
+		private const int EM_SETSCROLLPOS = WM_USER + 222;
 
 		internal const int ES_WANTRETURN = 0x1000;
 
@@ -153,9 +164,6 @@ namespace KeePass.Native
 		internal const int PBT_APMQUERYSUSPEND = 0x0000;
 		internal const int PBT_APMSUSPEND = 0x0004;
 
-		internal const int ECM_FIRST = 0x1500;
-		internal const int EM_SETCUEBANNER = ECM_FIRST + 1;
-
 		internal const uint INVALID_FILE_ATTRIBUTES = 0xFFFFFFFFU;
 
 		internal const uint FSCTL_LOCK_VOLUME = 589848;
@@ -167,6 +175,7 @@ namespace KeePass.Native
 		internal const int LVM_FIRST = 0x1000;
 		// internal const int LVM_ENSUREVISIBLE = LVM_FIRST + 19;
 		internal const int LVM_SCROLL = LVM_FIRST + 20;
+		internal const int LVM_GETTOOLTIPS = LVM_FIRST + 78;
 		// internal const int LVM_SETGROUPINFO = LVM_FIRST + 147; // >= Vista
 		// internal const int LVM_GETGROUPINFOBYINDEX = LVM_FIRST + 153; // >= Vista
 
@@ -176,7 +185,9 @@ namespace KeePass.Native
 
 		internal const int TTM_SETDELAYTIME = WM_USER + 3;
 		internal const int TTM_GETDELAYTIME = WM_USER + 21;
+		internal const int TTDT_RESHOW = 1;
 		internal const int TTDT_AUTOPOP = 2;
+		internal const int TTDT_INITIAL = 3;
 
 		internal const int WM_MOUSEACTIVATE = 0x21;
 		internal const int MA_ACTIVATE = 1;
@@ -184,6 +195,8 @@ namespace KeePass.Native
 		internal const int MA_NOACTIVATE = 3;
 		internal const int MA_NOACTIVATEANDEAT = 4;
 
+		internal const int IDI_SHIELD = 32518;
+
 		internal const int BCM_SETSHIELD = 0x160C;
 
 		internal const int SHCNE_ASSOCCHANGED = 0x08000000;
@@ -231,8 +244,8 @@ namespace KeePass.Native
 		internal const uint CF_UNICODETEXT = 13;
 
 		internal const uint SND_ASYNC = 0x0001;
-		internal const uint SND_FILENAME = 0x00020000;
 		internal const uint SND_NODEFAULT = 0x0002;
+		internal const uint SND_FILENAME = 0x00020000;
 
 		internal const int LOGPIXELSX = 88;
 		internal const int LOGPIXELSY = 90;
@@ -293,9 +306,12 @@ namespace KeePass.Native
 		internal const uint WDA_NONE = 0x00000000;
 		internal const uint WDA_MONITOR = 0x00000001;
 
+		internal const uint SPI_GETSCREENREADER = 0x0046;
+
 		[return: MarshalAs(UnmanagedType.Bool)]
 		internal delegate bool EnumWindowsProc(IntPtr hWnd, IntPtr lParam);
 
+		// Not [Flags]
 		internal enum ComboBoxButtonState : uint
 		{
 			STATE_SYSTEM_NONE = 0,
@@ -344,7 +360,7 @@ namespace KeePass.Native
 			TruncateExisting = 5
 		}
 
-		private enum ScrollBarDirection : int
+		internal enum ScrollBarDirection : int
 		{
 			SB_HORZ = 0,
 			SB_VERT = 1,
@@ -362,6 +378,23 @@ namespace KeePass.Native
 			SIF_ALL = (SIF_RANGE | SIF_PAGE | SIF_POS | SIF_TRACKPOS)
 		}
 
+		[Flags]
+		private enum RedrawWindowFlags : uint
+		{
+			RDW_INVALIDATE = 0x0001,
+			RDW_INTERNALPAINT = 0x0002,
+			RDW_ERASE = 0x0004,
+			RDW_VALIDATE = 0x0008,
+			RDW_NOINTERNALPAINT = 0x0010,
+			RDW_NOERASE = 0x0020,
+			RDW_NOCHILDREN = 0x0040,
+			RDW_ALLCHILDREN = 0x0080,
+			RDW_UPDATENOW = 0x0100,
+			RDW_ERASENOW = 0x0200,
+			RDW_FRAME = 0x0400,
+			RDW_NOFRAME = 0x0800
+		}
+
 		[Flags]
 		internal enum MessageBoxFlags : uint
 		{
