@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@ using System.Diagnostics;
 using System.Drawing;
 using System.IO;
 using System.Runtime.InteropServices;
-using System.Security;
 using System.Text;
 using System.Windows.Forms;
 
@@ -60,9 +59,7 @@ namespace KeePass.Native
 				int cb = (cc + 2) * cbChar;
 				p = Marshal.AllocCoTaskMem(cb);
 				if(p == IntPtr.Zero) { Debug.Assert(false); return string.Empty; }
-
-				byte[] pbZero = new byte[cb];
-				Marshal.Copy(pbZero, 0, p, cb);
+				MemUtil.ZeroMemory(p, cb);
 
 				int ccReal = GetWindowText(hWnd, p, cc + 1);
 				if(ccReal <= 0) { Debug.Assert(false); return string.Empty; }
@@ -84,6 +81,42 @@ namespace KeePass.Native
 			return (bTrim ? strWindow.Trim() : strWindow);
 		}
 
+		internal static char[] GetWindowTextV(IntPtr hWnd, bool bZeroBuffer)
+		{
+			if(hWnd == IntPtr.Zero) { Debug.Assert(false); return MemUtil.EmptyArray<char>(); }
+
+			int cc = GetWindowTextLength(hWnd);
+			if(cc <= 0) return MemUtil.EmptyArray<char>();
+
+			int cb = (cc + 2) * Marshal.SystemDefaultCharSize;
+
+			char[] v;
+			IntPtr p = IntPtr.Zero;
+			try
+			{
+				p = Marshal.AllocCoTaskMem(cb);
+				if(p == IntPtr.Zero) { Debug.Assert(false); return MemUtil.EmptyArray<char>(); }
+				MemUtil.ZeroMemory(p, cb);
+
+				int ccReal = GetWindowText(hWnd, p, cc + 1);
+				if(ccReal <= 0) { Debug.Assert(false); return MemUtil.EmptyArray<char>(); }
+
+				v = new char[ccReal];
+				Marshal.Copy(p, v, 0, ccReal);
+				Debug.Assert(Array.IndexOf(v, '\0') < 0);
+			}
+			finally
+			{
+				if(p != IntPtr.Zero)
+				{
+					if(bZeroBuffer) MemUtil.ZeroMemory(p, cb);
+					Marshal.FreeCoTaskMem(p);
+				}
+			}
+
+			return v;
+		}
+
 		/* internal static string GetWindowClassName(IntPtr hWnd)
 		{
 			try
@@ -193,6 +226,32 @@ namespace KeePass.Native
 			return false;
 		}
 
+		// Workaround for .NET/Windows TopMost/WS_EX_TOPMOST desynchronization bug;
+		// https://sourceforge.net/p/keepass/discussion/329220/thread/d45a3b38e8/
+		internal static void SyncTopMost(Form f)
+		{
+			if(f == null) { Debug.Assert(false); return; }
+			if(NativeLib.IsUnix()) return;
+
+			try
+			{
+				if(!f.TopMost) return; // Managed state
+
+				IntPtr h = f.Handle;
+				if(h == IntPtr.Zero) return;
+
+				int s = GetWindowLong(h, GWL_EXSTYLE); // Unmanaged state
+				if((s & WS_EX_TOPMOST) == 0)
+				{
+					f.TopMost = true; // Calls SetWindowPos (if TopLevel)
+#if DEBUG
+					Trace.WriteLine("Synchronized TopMost/WS_EX_TOPMOST.");
+#endif
+				}
+			}
+			catch(Exception) { Debug.Assert(false); }
+		}
+
 		internal static IntPtr FindWindow(string strTitle)
 		{
 			if(strTitle == null) { Debug.Assert(false); return IntPtr.Zero; }
@@ -354,19 +413,18 @@ namespace KeePass.Native
 			catch(Exception) { Debug.Assert(false); }
 		} */
 
-		public static int GetScrollPosY(IntPtr hWnd)
+		internal static int GetScrollPos(IntPtr hWnd, ScrollBarDirection d)
 		{
+			if(hWnd == IntPtr.Zero) { Debug.Assert(false); return 0; }
 			if(NativeLib.IsUnix()) return 0;
 
 			try
 			{
 				SCROLLINFO si = new SCROLLINFO();
-				si.cbSize = (uint)Marshal.SizeOf(si);
+				si.cbSize = (uint)Marshal.SizeOf(typeof(SCROLLINFO));
 				si.fMask = (uint)ScrollInfoMask.SIF_POS;
 
-				if(GetScrollInfo(hWnd, (int)ScrollBarDirection.SB_VERT, ref si))
-					return si.nPos;
-
+				if(GetScrollInfo(hWnd, (int)d, ref si)) return si.nPos;
 				Debug.Assert(false);
 			}
 			catch(Exception) { Debug.Assert(false); }
@@ -374,6 +432,56 @@ namespace KeePass.Native
 			return 0;
 		}
 
+		/* internal static void SetScrollPos(IntPtr hWnd, ScrollBarDirection d, int nPos)
+		{
+			if(hWnd == IntPtr.Zero) { Debug.Assert(false); return; }
+			if(NativeLib.IsUnix()) return;
+
+			try
+			{
+				SCROLLINFO si = new SCROLLINFO();
+				si.cbSize = (uint)Marshal.SizeOf(typeof(SCROLLINFO));
+				si.fMask = (uint)ScrollInfoMask.SIF_POS;
+				si.nPos = nPos;
+
+				SetScrollInfo(hWnd, (int)d, ref si, true);
+			}
+			catch(Exception) { Debug.Assert(false); }
+		} */
+
+		internal static POINT GetScrollPos(RichTextBox rtb)
+		{
+			POINT pt = new POINT();
+			if(rtb == null) { Debug.Assert(false); return pt; }
+			if(NativeLib.IsUnix()) return pt;
+
+			try
+			{
+				IntPtr hWnd = rtb.Handle;
+				if(hWnd != IntPtr.Zero)
+					SendMessagePoint(hWnd, EM_GETSCROLLPOS, IntPtr.Zero, ref pt);
+				else { Debug.Assert(false); }
+			}
+			catch(Exception) { Debug.Assert(false); }
+
+			return pt;
+		}
+
+		internal static void SetScrollPos(RichTextBox rtb, POINT pt)
+		{
+			if(rtb == null) { Debug.Assert(false); return; }
+			if(NativeLib.IsUnix()) return;
+
+			try
+			{
+				IntPtr hWnd = rtb.Handle;
+				if(hWnd != IntPtr.Zero)
+					SendMessagePoint(hWnd, EM_SETSCROLLPOS, IntPtr.Zero, ref pt);
+				else { Debug.Assert(false); }
+			}
+			catch(Exception) { Debug.Assert(false); }
+		}
+
 		public static void Scroll(ListView lv, int dx, int dy)
 		{
 			if(lv == null) throw new ArgumentNullException("lv");
@@ -383,20 +491,6 @@ namespace KeePass.Native
 			catch(Exception) { Debug.Assert(false); }
 		}
 
-		/* public static void ScrollAbsY(IntPtr hWnd, int y)
-		{
-			try
-			{
-				SCROLLINFO si = new SCROLLINFO();
-				si.cbSize = (uint)Marshal.SizeOf(si);
-				si.fMask = (uint)ScrollInfoMask.SIF_POS;
-				si.nPos = y;
-
-				SetScrollInfo(hWnd, (int)ScrollBarDirection.SB_VERT, ref si, true);
-			}
-			catch(Exception) { Debug.Assert(false); }
-		} */
-
 		/* public static void Scroll(IntPtr h, int dx, int dy)
 		{
 			if(h == IntPtr.Zero) { Debug.Assert(false); return; } // No throw
@@ -418,6 +512,24 @@ namespace KeePass.Native
 			catch(Exception) { Debug.Assert(!WinUtil.IsAtLeastWindows7); }
 		} */
 
+		internal static void SetRedraw(IntPtr hWnd, bool bEnable, bool bRedrawNow)
+		{
+			if(hWnd == IntPtr.Zero) { Debug.Assert(false); return; }
+			if(NativeLib.IsUnix()) return;
+
+			try
+			{
+				SendMessage(hWnd, WM_SETREDRAW, (bEnable ? TRUE_PTR : FALSE_PTR), IntPtr.Zero);
+
+				// https://learn.microsoft.com/en-us/windows/win32/gdi/wm-setredraw
+				if(bRedrawNow)
+					RedrawWindow(hWnd, IntPtr.Zero, IntPtr.Zero,
+						RedrawWindowFlags.RDW_ERASE | RedrawWindowFlags.RDW_FRAME |
+						RedrawWindowFlags.RDW_INVALIDATE | RedrawWindowFlags.RDW_ALLCHILDREN);
+			}
+			catch(Exception) { Debug.Assert(false); }
+		}
+
 		internal static uint? GetLastInputTime()
 		{
 			try
@@ -535,7 +647,7 @@ namespace KeePass.Native
 				throw new ArgumentOutOfRangeException("uIndex");
 
 			LVGROUP g = new LVGROUP();
-			g.cbSize = (uint)Marshal.SizeOf(g);
+			g.cbSize = (uint)Marshal.SizeOf(typeof(LVGROUP));
 
 			g.mask = (LVGF_STATE | LVGF_GROUPID);
 			g.stateMask = uStateMask;
@@ -553,7 +665,7 @@ namespace KeePass.Native
 			if(lv == null) throw new ArgumentNullException("lv");
 
 			LVGROUP g = new LVGROUP();
-			g.cbSize = (uint)Marshal.SizeOf(g);
+			g.cbSize = (uint)Marshal.SizeOf(typeof(LVGROUP));
 
 			g.mask = LVGF_STATE;
 			g.stateMask = uStateMask;
@@ -568,7 +680,7 @@ namespace KeePass.Native
 			if(lv == null) { Debug.Assert(false); return 0; }
 
 			LVGROUP g = new LVGROUP();
-			g.cbSize = (uint)Marshal.SizeOf(g);
+			g.cbSize = (uint)Marshal.SizeOf(typeof(LVGROUP));
 			g.AssertSize();
 
 			g.mask = NativeMethods.LVGF_GROUPID;
@@ -588,7 +700,7 @@ namespace KeePass.Native
 			if(lv == null) { Debug.Assert(false); return; }
 
 			LVGROUP g = new LVGROUP();
-			g.cbSize = (uint)Marshal.SizeOf(g);
+			g.cbSize = (uint)Marshal.SizeOf(typeof(LVGROUP));
 			g.AssertSize();
 
 			g.mask = LVGF_TASK;
@@ -610,7 +722,7 @@ namespace KeePass.Native
 			if(!WinUtil.IsAtLeastWindowsVista) return;
 
 			LVGROUP g = new LVGROUP();
-			g.cbSize = (uint)Marshal.SizeOf(g);
+			g.cbSize = (uint)Marshal.SizeOf(typeof(LVGROUP));
 			g.AssertSize();
 
 			if(strTask != null)
@@ -656,41 +768,40 @@ namespace KeePass.Native
 			strAnsi = null;
 			strUni = null;
 
-			const uint cbZ = 12; // Minimal number of terminating zeros
-			const uint uBufSize = 64 + cbZ;
-			IntPtr pBuf = Marshal.AllocCoTaskMem((int)uBufSize);
-			byte[] pbZero = new byte[uBufSize];
-			Marshal.Copy(pbZero, 0, pBuf, pbZero.Length);
+			const uint cbZ = 12; // Minimal number of terminating zero bytes
+
+			uint cb = 64 + cbZ;
+			IntPtr p = Marshal.AllocCoTaskMem((int)cb);
+			MemUtil.ZeroMemory(p, (long)cb);
 
 			try
 			{
-				uint uReqSize = uBufSize - cbZ;
-				bool bSuccess = GetUserObjectInformation(hDesk, 2, pBuf,
-					uBufSize - cbZ, ref uReqSize);
-				if(uReqSize > (uBufSize - cbZ))
+				uint cbReq = cb - cbZ;
+				bool bSuccess = GetUserObjectInformation(hDesk, 2, p, cbReq, ref cbReq);
+				if(cbReq > (cb - cbZ))
 				{
-					Marshal.FreeCoTaskMem(pBuf);
-					pBuf = Marshal.AllocCoTaskMem((int)(uReqSize + cbZ));
-					pbZero = new byte[uReqSize + cbZ];
-					Marshal.Copy(pbZero, 0, pBuf, pbZero.Length);
+					Marshal.FreeCoTaskMem(p);
 
-					bSuccess = GetUserObjectInformation(hDesk, 2, pBuf,
-						uReqSize, ref uReqSize);
-					Debug.Assert((uReqSize + cbZ) == (uint)pbZero.Length);
+					cb = cbReq + cbZ;
+					p = Marshal.AllocCoTaskMem((int)cb);
+					MemUtil.ZeroMemory(p, (long)cb);
+
+					bSuccess = GetUserObjectInformation(hDesk, 2, p, cbReq, ref cbReq);
+					Debug.Assert((cbReq + cbZ) == cb);
 				}
 
 				if(bSuccess)
 				{
-					try { strAnsi = Marshal.PtrToStringAnsi(pBuf).Trim(); }
+					try { strAnsi = Marshal.PtrToStringAnsi(p).Trim(); }
 					catch(Exception) { }
 
-					try { strUni = Marshal.PtrToStringUni(pBuf).Trim(); }
+					try { strUni = Marshal.PtrToStringUni(p).Trim(); }
 					catch(Exception) { }
 
 					return true;
 				}
 			}
-			finally { Marshal.FreeCoTaskMem(pBuf); }
+			finally { Marshal.FreeCoTaskMem(p); }
 
 			Debug.Assert(false);
 			return false;
@@ -850,5 +961,10 @@ namespace KeePass.Native
 
 			return null;
 		}
+
+		internal static IntPtr MakeIntResource(int i)
+		{
+			return new IntPtr(i & 0xFFFF);
+		}
 	}
 }
