@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2020 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,13 +20,13 @@
 using System;
 using System.Collections.Generic;
 using System.Diagnostics;
-using System.Text.RegularExpressions;
+using System.Text;
 
 using KeePassLib.Collections;
 using KeePassLib.Delegates;
 using KeePassLib.Interfaces;
+using KeePassLib.Native;
 using KeePassLib.Resources;
-using KeePassLib.Security;
 using KeePassLib.Utility;
 
 namespace KeePassLib
@@ -34,7 +34,7 @@ namespace KeePassLib
 	/// <summary>
 	/// A group containing subgroups and entries.
 	/// </summary>
-	public sealed class PwGroup : ITimeLogger, IStructureItem, IDeepCloneable<PwGroup>
+	public sealed partial class PwGroup : ITimeLogger, IStructureItem, IDeepCloneable<PwGroup>
 	{
 		public const bool DefaultAutoTypeEnabled = true;
 		public const bool DefaultSearchingEnabled = true;
@@ -43,12 +43,14 @@ namespace KeePassLib
 		// to 0 after 256 nested nodes
 		private const uint MaxDepth = 126; // Depth 126 = level 127 < 256/2
 
-		private PwObjectList<PwGroup> m_listGroups = new PwObjectList<PwGroup>();
-		private PwObjectList<PwEntry> m_listEntries = new PwObjectList<PwEntry>();
+		private PwUuid m_uuid = PwUuid.Zero;
 		private PwGroup m_pParentGroup = null;
 		private DateTime m_tParentGroupLastMod = PwDefs.DtDefaultNow;
+		private PwUuid m_puPrevParentGroup = PwUuid.Zero;
+
+		private PwObjectList<PwGroup> m_listGroups = new PwObjectList<PwGroup>();
+		private PwObjectList<PwEntry> m_listEntries = new PwObjectList<PwEntry>();
 
-		private PwUuid m_uuid = PwUuid.Zero;
 		private string m_strName = string.Empty;
 		private string m_strNotes = string.Empty;
 
@@ -67,11 +69,13 @@ namespace KeePassLib
 
 		private string m_strDefaultAutoTypeSequence = string.Empty;
 
-		private bool? m_bEnableAutoType = null;
-		private bool? m_bEnableSearching = null;
+		private bool? m_obEnableAutoType = null;
+		private bool? m_obEnableSearching = null;
 
 		private PwUuid m_pwLastTopVisibleEntry = PwUuid.Zero;
 
+		private List<string> m_lTags = new List<string>();
+
 		private StringDictionaryEx m_dCustomData = new StringDictionaryEx();
 
 		/// <summary>
@@ -87,6 +91,37 @@ namespace KeePassLib
 			}
 		}
 
+		/// <summary>
+		/// Reference to the group to which this group belongs. May be <c>null</c>.
+		/// </summary>
+		public PwGroup ParentGroup
+		{
+			get { return m_pParentGroup; }
+
+			// Plugins: use the PwGroup.AddGroup method instead.
+			// Internal: check depth using CanAddGroup/CheckCanAddGroup.
+			internal set { Debug.Assert(value != this); m_pParentGroup = value; }
+		}
+
+		/// <summary>
+		/// The date/time when the location of the object was last changed.
+		/// </summary>
+		public DateTime LocationChanged
+		{
+			get { return m_tParentGroupLastMod; }
+			set { m_tParentGroupLastMod = value; }
+		}
+
+		public PwUuid PreviousParentGroup
+		{
+			get { return m_puPrevParentGroup; }
+			set
+			{
+				if(value == null) { Debug.Assert(false); throw new ArgumentNullException("value"); }
+				m_puPrevParentGroup = value;
+			}
+		}
+
 		/// <summary>
 		/// The name of this group. Cannot be <c>null</c>.
 		/// </summary>
@@ -137,27 +172,6 @@ namespace KeePassLib
 			}
 		}
 
-		/// <summary>
-		/// Reference to the group to which this group belongs. May be <c>null</c>.
-		/// </summary>
-		public PwGroup ParentGroup
-		{
-			get { return m_pParentGroup; }
-
-			// Plugins: use the PwGroup.AddGroup method instead.
-			// Internal: check depth using CanAddGroup/CheckCanAddGroup.
-			internal set { Debug.Assert(value != this); m_pParentGroup = value; }
-		}
-
-		/// <summary>
-		/// The date/time when the location of the object was last changed.
-		/// </summary>
-		public DateTime LocationChanged
-		{
-			get { return m_tParentGroupLastMod; }
-			set { m_tParentGroupLastMod = value; }
-		}
-
 		/// <summary>
 		/// A flag that specifies if the group is shown as expanded or
 		/// collapsed in the user interface.
@@ -269,14 +283,14 @@ namespace KeePassLib
 
 		public bool? EnableAutoType
 		{
-			get { return m_bEnableAutoType; }
-			set { m_bEnableAutoType = value; }
+			get { return m_obEnableAutoType; }
+			set { m_obEnableAutoType = value; }
 		}
 
 		public bool? EnableSearching
 		{
-			get { return m_bEnableSearching; }
-			set { m_bEnableSearching = value; }
+			get { return m_obEnableSearching; }
+			set { m_obEnableSearching = value; }
 		}
 
 		public PwUuid LastTopVisibleEntry
@@ -289,6 +303,16 @@ namespace KeePassLib
 			}
 		}
 
+		public List<string> Tags
+		{
+			get { StrUtil.NormalizeTags(m_lTags); return m_lTags; }
+			set
+			{
+				if(value == null) { Debug.Assert(false); throw new ArgumentNullException("value"); }
+				m_lTags = value;
+			}
+		}
+
 		/// <summary>
 		/// Custom data container that can be used by plugins to store
 		/// own data in KeePass groups.
@@ -381,8 +405,11 @@ namespace KeePassLib
 
 			pg.m_listGroups = m_listGroups.CloneDeep();
 			pg.m_listEntries = m_listEntries.CloneDeep();
+			pg.TakeOwnership(true, true, false);
+
 			pg.m_pParentGroup = m_pParentGroup;
 			pg.m_tParentGroupLastMod = m_tParentGroupLastMod;
+			pg.m_puPrevParentGroup = m_puPrevParentGroup;
 
 			pg.m_strName = m_strName;
 			pg.m_strNotes = m_strNotes;
@@ -402,11 +429,13 @@ namespace KeePassLib
 
 			pg.m_strDefaultAutoTypeSequence = m_strDefaultAutoTypeSequence;
 
-			pg.m_bEnableAutoType = m_bEnableAutoType;
-			pg.m_bEnableSearching = m_bEnableSearching;
+			pg.m_obEnableAutoType = m_obEnableAutoType;
+			pg.m_obEnableSearching = m_obEnableSearching;
 
 			pg.m_pwLastTopVisibleEntry = m_pwLastTopVisibleEntry;
 
+			pg.m_lTags.AddRange(m_lTags);
+
 			pg.m_dCustomData = m_dCustomData.CloneDeep();
 
 			return pg;
@@ -443,7 +472,10 @@ namespace KeePassLib
 			if((pwOpt & PwCompareOptions.IgnoreParentGroup) == PwCompareOptions.None)
 			{
 				if(m_pParentGroup != pg.m_pParentGroup) return false;
-				if(!bIgnoreLastMod && (m_tParentGroupLastMod != pg.m_tParentGroupLastMod))
+				if(!bIgnoreLastMod && !TimeUtil.EqualsFloor(m_tParentGroupLastMod,
+					pg.m_tParentGroupLastMod))
+					return false;
+				if(!m_puPrevParentGroup.Equals(pg.m_puPrevParentGroup))
 					return false;
 			}
 
@@ -453,10 +485,10 @@ namespace KeePassLib
 			if(m_pwIcon != pg.m_pwIcon) return false;
 			if(!m_pwCustomIconID.Equals(pg.m_pwCustomIconID)) return false;
 
-			if(m_tCreation != pg.m_tCreation) return false;
-			if(!bIgnoreLastMod && (m_tLastMod != pg.m_tLastMod)) return false;
-			if(!bIgnoreLastAccess && (m_tLastAccess != pg.m_tLastAccess)) return false;
-			if(m_tExpire != pg.m_tExpire) return false;
+			if(!TimeUtil.EqualsFloor(m_tCreation, pg.m_tCreation)) return false;
+			if(!bIgnoreLastMod && !TimeUtil.EqualsFloor(m_tLastMod, pg.m_tLastMod)) return false;
+			if(!bIgnoreLastAccess && !TimeUtil.EqualsFloor(m_tLastAccess, pg.m_tLastAccess)) return false;
+			if(!TimeUtil.EqualsFloor(m_tExpire, pg.m_tExpire)) return false;
 			if(m_bExpires != pg.m_bExpires) return false;
 			if(!bIgnoreLastAccess && (m_uUsageCount != pg.m_uUsageCount)) return false;
 
@@ -464,19 +496,22 @@ namespace KeePassLib
 
 			if(m_strDefaultAutoTypeSequence != pg.m_strDefaultAutoTypeSequence) return false;
 
-			if(m_bEnableAutoType.HasValue != pg.m_bEnableAutoType.HasValue) return false;
-			if(m_bEnableAutoType.HasValue)
+			if(m_obEnableAutoType.HasValue != pg.m_obEnableAutoType.HasValue) return false;
+			if(m_obEnableAutoType.HasValue)
 			{
-				if(m_bEnableAutoType.Value != pg.m_bEnableAutoType.Value) return false;
+				if(m_obEnableAutoType.Value != pg.m_obEnableAutoType.Value) return false;
 			}
-			if(m_bEnableSearching.HasValue != pg.m_bEnableSearching.HasValue) return false;
-			if(m_bEnableSearching.HasValue)
+			if(m_obEnableSearching.HasValue != pg.m_obEnableSearching.HasValue) return false;
+			if(m_obEnableSearching.HasValue)
 			{
-				if(m_bEnableSearching.Value != pg.m_bEnableSearching.Value) return false;
+				if(m_obEnableSearching.Value != pg.m_obEnableSearching.Value) return false;
 			}
 
 			if(!m_pwLastTopVisibleEntry.Equals(pg.m_pwLastTopVisibleEntry)) return false;
 
+			// The Tags property normalizes
+			if(!MemUtil.ListsEqual<string>(this.Tags, pg.Tags)) return false;
+
 			if(!m_dCustomData.Equals(pg.m_dCustomData)) return false;
 
 			if((pwOpt & PwCompareOptions.PropertiesOnly) == PwCompareOptions.None)
@@ -523,7 +558,10 @@ namespace KeePassLib
 			m_uuid = pgTemplate.m_uuid;
 
 			if(bAssignLocationChanged)
+			{
 				m_tParentGroupLastMod = pgTemplate.m_tParentGroupLastMod;
+				m_puPrevParentGroup = pgTemplate.m_puPrevParentGroup;
+			}
 
 			m_strName = pgTemplate.m_strName;
 			m_strNotes = pgTemplate.m_strNotes;
@@ -540,11 +578,13 @@ namespace KeePassLib
 
 			m_strDefaultAutoTypeSequence = pgTemplate.m_strDefaultAutoTypeSequence;
 
-			m_bEnableAutoType = pgTemplate.m_bEnableAutoType;
-			m_bEnableSearching = pgTemplate.m_bEnableSearching;
+			m_obEnableAutoType = pgTemplate.m_obEnableAutoType;
+			m_obEnableSearching = pgTemplate.m_obEnableSearching;
 
 			m_pwLastTopVisibleEntry = pgTemplate.m_pwLastTopVisibleEntry;
 
+			m_lTags = new List<string>(pgTemplate.m_lTags);
+
 			m_dCustomData = pgTemplate.m_dCustomData.CloneDeep();
 		}
 
@@ -769,327 +809,95 @@ namespace KeePassLib
 			return PreOrderTraverseTree(null, eh);
 		}
 
-		/// <summary>
-		/// Search this group and all subgroups for entries.
-		/// </summary>
-		/// <param name="sp">Specifies the search parameters.</param>
-		/// <param name="lResults">Entry list in which the search results
-		/// will be stored.</param>
-		public void SearchEntries(SearchParameters sp, PwObjectList<PwEntry> lResults)
+		internal List<string> GetTagsInherited(bool bNormalize)
 		{
-			SearchEntries(sp, lResults, null);
-		}
+			List<string> l = new List<string>();
 
-		/// <summary>
-		/// Search this group and all subgroups for entries.
-		/// </summary>
-		/// <param name="sp">Specifies the search parameters.</param>
-		/// <param name="lResults">Entry list in which the search results
-		/// will be stored.</param>
-		/// <param name="slStatus">Optional status reporting object.</param>
-		public void SearchEntries(SearchParameters sp, PwObjectList<PwEntry> lResults,
-			IStatusLogger slStatus)
-		{
-			if(sp == null) { Debug.Assert(false); return; }
-			if(lResults == null) { Debug.Assert(false); return; }
-
-			PwObjectList<PwEntry> lCand = GetEntries(true);
-			DateTime dtNow = DateTime.UtcNow;
-
-			PwObjectList<PwEntry> l = new PwObjectList<PwEntry>();
-			foreach(PwEntry pe in lCand)
+			PwGroup pg = this;
+			while(pg != null)
 			{
-				if(sp.RespectEntrySearchingDisabled && !pe.GetSearchingEnabled())
-					continue;
-				if(sp.ExcludeExpired && pe.Expires && (pe.ExpiryTime <= dtNow))
-					continue;
-
-				l.Add(pe);
-			}
-			lCand = l;
-
-			List<string> lTerms;
-			if(sp.RegularExpression)
-			{
-				lTerms = new List<string>();
-				lTerms.Add((sp.SearchString ?? string.Empty).Trim());
-			}
-			else lTerms = StrUtil.SplitSearchTerms(sp.SearchString);
-
-			// Search longer strings first (for improved performance)
-			lTerms.Sort(StrUtil.CompareLengthGt);
-
-			ulong uPrcEntries = 0, uTotalEntries = lCand.UCount;
-			SearchParameters spSub = sp.Clone();
-
-			for(int iTerm = 0; iTerm < lTerms.Count; ++iTerm)
-			{
-				// Update counters for a better state guess
-				if(slStatus != null)
-				{
-					ulong uRemRounds = (ulong)(lTerms.Count - iTerm);
-					uTotalEntries = uPrcEntries + (uRemRounds *
-						lCand.UCount);
-				}
-
-				spSub.SearchString = lTerms[iTerm]; // No trim
-				// spSub.RespectEntrySearchingDisabled = false; // Ignored by sub
-				// spSub.ExcludeExpired = false; // Ignored by sub
-
-				bool bNegate = false;
-				if(spSub.SearchString.StartsWith(@"-") &&
-					(spSub.SearchString.Length >= 2))
-				{
-					spSub.SearchString = spSub.SearchString.Substring(1);
-					bNegate = true;
-				}
-
-				l = new PwObjectList<PwEntry>();
-				if(!SearchEntriesSingle(lCand, spSub, l, slStatus,
-					ref uPrcEntries, uTotalEntries))
-				{
-					lCand.Clear();
-					break;
-				}
-
-				if(bNegate)
-				{
-					PwObjectList<PwEntry> lRem = new PwObjectList<PwEntry>();
-					foreach(PwEntry pe in lCand)
-					{
-						if(l.IndexOf(pe) < 0) lRem.Add(pe);
-					}
-
-					lCand = lRem;
-				}
-				else lCand = l;
+				l.AddRange(pg.Tags);
+				pg = pg.m_pParentGroup;
 			}
 
-			Debug.Assert(lResults.UCount == 0);
-			lResults.Clear();
-			lResults.Add(lCand);
-		}
-
-		private static bool SearchEntriesSingle(PwObjectList<PwEntry> lSource,
-			SearchParameters sp, PwObjectList<PwEntry> lResults,
-			IStatusLogger slStatus, ref ulong uPrcEntries, ulong uTotalEntries)
-		{
-			if(lSource == null) { Debug.Assert(false); return true; }
-			if(sp == null) { Debug.Assert(false); return true; }
-			if(lResults == null) { Debug.Assert(false); return true; }
-			Debug.Assert(lResults.UCount == 0);
-
-			bool bTitle = sp.SearchInTitles;
-			bool bUserName = sp.SearchInUserNames;
-			bool bPassword = sp.SearchInPasswords;
-			bool bUrl = sp.SearchInUrls;
-			bool bNotes = sp.SearchInNotes;
-			bool bOther = sp.SearchInOther;
-			bool bStringName = sp.SearchInStringNames;
-			bool bTags = sp.SearchInTags;
-			bool bUuids = sp.SearchInUuids;
-			bool bGroupPath = sp.SearchInGroupPaths;
-			bool bGroupName = sp.SearchInGroupNames;
-			// bool bExcludeExpired = sp.ExcludeExpired;
-			// bool bRespectEntrySearchingDisabled = sp.RespectEntrySearchingDisabled;
-
-			if(bGroupPath) bGroupName = false; // Name is included in path
-
-			Regex rx = null;
-			if(sp.RegularExpression)
-			{
-				RegexOptions ro = RegexOptions.None; // RegexOptions.Compiled
-				if((sp.ComparisonMode == StringComparison.CurrentCultureIgnoreCase) ||
-#if !KeePassUAP
-					(sp.ComparisonMode == StringComparison.InvariantCultureIgnoreCase) ||
-#endif
-					(sp.ComparisonMode == StringComparison.OrdinalIgnoreCase))
-				{
-					ro |= RegexOptions.IgnoreCase;
-				}
-
-				rx = new Regex(sp.SearchString, ro);
-			}
-
-			ulong uLocalPrcEntries = uPrcEntries;
-
-			if(sp.SearchString.Length == 0) lResults.Add(lSource);
-			else
-			{
-				foreach(PwEntry pe in lSource)
-				{
-					if(slStatus != null)
-					{
-						if(!slStatus.SetProgress((uint)((uLocalPrcEntries *
-							100UL) / uTotalEntries))) return false;
-						++uLocalPrcEntries;
-					}
-
-					// if(bRespectEntrySearchingDisabled && !pe.GetSearchingEnabled())
-					//	continue;
-					// if(bExcludeExpired && pe.Expires && (pe.ExpiryTime <= dtNow))
-					//	continue;
-
-					uint uInitialResults = lResults.UCount;
-
-					foreach(KeyValuePair<string, ProtectedString> kvp in pe.Strings)
-					{
-						string strKey = kvp.Key;
-
-						if(strKey == PwDefs.TitleField)
-						{
-							if(bTitle) SearchEvalAdd(sp, kvp.Value.ReadString(),
-								rx, pe, lResults);
-						}
-						else if(strKey == PwDefs.UserNameField)
-						{
-							if(bUserName) SearchEvalAdd(sp, kvp.Value.ReadString(),
-								rx, pe, lResults);
-						}
-						else if(strKey == PwDefs.PasswordField)
-						{
-							if(bPassword) SearchEvalAdd(sp, kvp.Value.ReadString(),
-								rx, pe, lResults);
-						}
-						else if(strKey == PwDefs.UrlField)
-						{
-							if(bUrl) SearchEvalAdd(sp, kvp.Value.ReadString(),
-								rx, pe, lResults);
-						}
-						else if(strKey == PwDefs.NotesField)
-						{
-							if(bNotes) SearchEvalAdd(sp, kvp.Value.ReadString(),
-								rx, pe, lResults);
-						}
-						else if(bOther)
-							SearchEvalAdd(sp, kvp.Value.ReadString(),
-								rx, pe, lResults);
-
-						// An entry can match only once => break if we have added it
-						if(lResults.UCount != uInitialResults) break;
-					}
-
-					if(bStringName)
-					{
-						foreach(KeyValuePair<string, ProtectedString> kvp in pe.Strings)
-						{
-							if(lResults.UCount != uInitialResults) break;
-
-							SearchEvalAdd(sp, kvp.Key, rx, pe, lResults);
-						}
-					}
-
-					if(bTags)
-					{
-						foreach(string strTag in pe.Tags)
-						{
-							if(lResults.UCount != uInitialResults) break;
-
-							SearchEvalAdd(sp, strTag, rx, pe, lResults);
-						}
-					}
-
-					if(bUuids && (lResults.UCount == uInitialResults))
-						SearchEvalAdd(sp, pe.Uuid.ToHexString(), rx, pe, lResults);
-
-					if(bGroupPath && (lResults.UCount == uInitialResults) &&
-						(pe.ParentGroup != null))
-						SearchEvalAdd(sp, pe.ParentGroup.GetFullPath("\n", true),
-							rx, pe, lResults);
-
-					if(bGroupName && (lResults.UCount == uInitialResults) &&
-						(pe.ParentGroup != null))
-						SearchEvalAdd(sp, pe.ParentGroup.Name, rx, pe, lResults);
-				}
-			}
-
-			uPrcEntries = uLocalPrcEntries;
-			return true;
-		}
-
-		private static void SearchEvalAdd(SearchParameters sp, string strData,
-			Regex rx, PwEntry pe, PwObjectList<PwEntry> lResults)
-		{
-			if(sp == null) { Debug.Assert(false); return; }
-			if(strData == null) { Debug.Assert(false); return; }
-			if(pe == null) { Debug.Assert(false); return; }
-			if(lResults == null) { Debug.Assert(false); return; }
-
-			bool bMatch;
-			if(rx == null)
-				bMatch = (strData.IndexOf(sp.SearchString,
-					sp.ComparisonMode) >= 0);
-			else bMatch = rx.IsMatch(strData);
-
-			if(!bMatch && (sp.DataTransformationFn != null))
-			{
-				string strCmp = sp.DataTransformationFn(strData, pe);
-				if(!object.ReferenceEquals(strCmp, strData))
-				{
-					if(rx == null)
-						bMatch = (strCmp.IndexOf(sp.SearchString,
-							sp.ComparisonMode) >= 0);
-					else bMatch = rx.IsMatch(strCmp);
-				}
-			}
-
-			if(bMatch) lResults.Add(pe);
+			if(bNormalize) StrUtil.NormalizeTags(l);
+			return l;
 		}
 
 		public List<string> BuildEntryTagsList()
 		{
-			return BuildEntryTagsList(false);
+			return BuildEntryTagsList(false, false);
 		}
 
 		public List<string> BuildEntryTagsList(bool bSort)
 		{
-			List<string> vTags = new List<string>();
+			return BuildEntryTagsList(bSort, false);
+		}
+
+		internal List<string> BuildEntryTagsList(bool bSort, bool bGroupTags)
+		{
+			Dictionary<string, bool> d = new Dictionary<string, bool>();
+
+			GroupHandler gh = null;
+			if(bGroupTags)
+			{
+				gh = delegate(PwGroup pg)
+				{
+					foreach(string strTag in pg.Tags) d[strTag] = true;
+					return true;
+				};
+			}
 
 			EntryHandler eh = delegate(PwEntry pe)
 			{
-				foreach(string strTag in pe.Tags)
-				{
-					bool bFound = false;
-					for(int i = 0; i < vTags.Count; ++i)
-					{
-						if(vTags[i].Equals(strTag, StrUtil.CaseIgnoreCmp))
-						{
-							bFound = true;
-							break;
-						}
-					}
-
-					if(!bFound) vTags.Add(strTag);
-				}
-
+				foreach(string strTag in pe.Tags) d[strTag] = true;
 				return true;
 			};
 
-			TraverseTree(TraversalMethod.PreOrder, null, eh);
-			if(bSort) vTags.Sort(StrUtil.CaseIgnoreComparer);
-			return vTags;
+			if(gh != null) gh(this);
+			TraverseTree(TraversalMethod.PreOrder, gh, eh);
+
+			List<string> l = new List<string>(d.Keys);
+			if(bSort) l.Sort(StrUtil.CompareNaturally);
+
+			return l;
 		}
 
 #if !KeePassLibSD
 		public IDictionary<string, uint> BuildEntryTagsDict(bool bSort)
 		{
-			IDictionary<string, uint> d;
-			if(!bSort) d = new Dictionary<string, uint>(StrUtil.CaseIgnoreComparer);
-			else d = new SortedDictionary<string, uint>(StrUtil.CaseIgnoreComparer);
+			Debug.Assert(!bSort); // Obsolete
 
-			EntryHandler eh = delegate(PwEntry pe)
+			IDictionary<string, uint> d;
+			if(!bSort) d = new Dictionary<string, uint>();
+			else d = new SortedDictionary<string, uint>();
+
+			GroupHandler gh = delegate(PwGroup pg)
 			{
-				foreach(string strTag in pe.Tags)
+				foreach(string strTag in pg.Tags)
 				{
-					uint u;
-					if(d.TryGetValue(strTag, out u)) d[strTag] = u + 1;
-					else d[strTag] = 1;
+					// For groups without entries
+					if(!d.ContainsKey(strTag)) d[strTag] = 0;
 				}
 
 				return true;
 			};
 
-			TraverseTree(TraversalMethod.PreOrder, null, eh);
+			EntryHandler eh = delegate(PwEntry pe)
+			{
+				foreach(string strTag in pe.GetTagsInherited())
+				{
+					uint u;
+					d.TryGetValue(strTag, out u);
+					d[strTag] = u + 1;
+				}
+
+				return true;
+			};
+
+			gh(this);
+			TraverseTree(TraversalMethod.PreOrder, gh, eh);
+
 			return d;
 		}
 #endif
@@ -1098,24 +906,29 @@ namespace KeePassLib
 			bool bSearchRecursive)
 		{
 			if(strTag == null) throw new ArgumentNullException("strTag");
-			if(strTag.Length == 0) return;
 
-			foreach(PwEntry pe in m_listEntries)
+			strTag = StrUtil.NormalizeTag(strTag);
+			if(string.IsNullOrEmpty(strTag)) return;
+
+			EntryHandler eh = delegate(PwEntry pe)
 			{
-				foreach(string strEntryTag in pe.Tags)
+				foreach(string strEntryTag in pe.GetTagsInherited())
 				{
-					if(strEntryTag.Equals(strTag, StrUtil.CaseIgnoreCmp))
+					if(strEntryTag == strTag)
 					{
 						listStorage.Add(pe);
 						break;
 					}
 				}
-			}
+
+				return true;
+			};
 
 			if(bSearchRecursive)
+				TraverseTree(TraversalMethod.PreOrder, null, eh);
+			else
 			{
-				foreach(PwGroup pg in m_listGroups)
-					pg.FindEntriesByTag(strTag, listStorage, true);
+				foreach(PwEntry pe in m_listEntries) eh(pe);
 			}
 		}
 
@@ -1224,22 +1037,20 @@ namespace KeePassLib
 		}
 
 		/// <summary>
-		/// Get the full path of a group.
+		/// Get the full path of the group.
 		/// </summary>
-		/// <returns>Full path of the group.</returns>
 		public string GetFullPath()
 		{
-			return GetFullPath(".", false);
+			return GetFullPath(false, false);
 		}
 
 		/// <summary>
-		/// Get the full path of a group.
+		/// Get the full path of the group.
 		/// </summary>
 		/// <param name="strSeparator">String that separates the group
 		/// names.</param>
 		/// <param name="bIncludeTopMostGroup">Specifies whether the returned
 		/// path starts with the topmost group.</param>
-		/// <returns>Full path of the group.</returns>
 		public string GetFullPath(string strSeparator, bool bIncludeTopMostGroup)
 		{
 			Debug.Assert(strSeparator != null);
@@ -1261,6 +1072,15 @@ namespace KeePassLib
 			return strPath;
 		}
 
+		internal string GetFullPath(bool bForDisplay, bool bIncludeTopMostGroup)
+		{
+			string strSep;
+			if(bForDisplay) strSep = (NativeLib.IsUnix() ? " - " : " \u2192 ");
+			else strSep = ".";
+
+			return GetFullPath(strSep, bIncludeTopMostGroup);
+		}
+
 		/// <summary>
 		/// Assign new UUIDs to groups and entries.
 		/// </summary>
@@ -1324,7 +1144,7 @@ namespace KeePassLib
 		public PwGroup FindCreateSubTree(string strTree, char[] vSeparators,
 			bool bAllowCreate)
 		{
-			if(vSeparators == null) { Debug.Assert(false); vSeparators = new char[0]; }
+			if(vSeparators == null) { Debug.Assert(false); vSeparators = MemUtil.EmptyArray<char>(); }
 
 			string[] v = new string[vSeparators.Length];
 			for(int i = 0; i < vSeparators.Length; ++i)
@@ -1416,7 +1236,7 @@ namespace KeePassLib
 
 		public bool GetAutoTypeEnabledInherited()
 		{
-			if(m_bEnableAutoType.HasValue) return m_bEnableAutoType.Value;
+			if(m_obEnableAutoType.HasValue) return m_obEnableAutoType.Value;
 
 			if(m_pParentGroup != null)
 				return m_pParentGroup.GetAutoTypeEnabledInherited();
@@ -1426,7 +1246,7 @@ namespace KeePassLib
 
 		public bool GetSearchingEnabledInherited()
 		{
-			if(m_bEnableSearching.HasValue) return m_bEnableSearching.Value;
+			if(m_obEnableSearching.HasValue) return m_obEnableSearching.Value;
 
 			if(m_pParentGroup != null)
 				return m_pParentGroup.GetSearchingEnabledInherited();
@@ -1444,7 +1264,7 @@ namespace KeePassLib
 		/// subgroups.</returns>
 		public PwObjectList<PwGroup> GetGroups(bool bRecursive)
 		{
-			if(bRecursive == false) return m_listGroups;
+			if(!bRecursive) return m_listGroups;
 
 			PwObjectList<PwGroup> list = m_listGroups.CloneShallow();
 			foreach(PwGroup pgSub in m_listGroups)
@@ -1643,7 +1463,7 @@ namespace KeePassLib
 
 		private void GetTopSearchSkippedGroupsRec(List<PwGroup> l)
 		{
-			if(m_bEnableSearching.HasValue && !m_bEnableSearching.Value)
+			if(m_obEnableSearching.HasValue && !m_obEnableSearching.Value)
 			{
 				l.Add(this);
 				return;
@@ -1689,14 +1509,12 @@ namespace KeePassLib
 
 			pg.SetCreatedNow(true);
 
-			pg.TakeOwnership(true, true, true);
-
 			return pg;
 		}
 
 		internal string[] CollectEntryStrings(GFunc<PwEntry, string> f, bool bSort)
 		{
-			if(f == null) { Debug.Assert(false); return new string[0]; }
+			if(f == null) { Debug.Assert(false); return MemUtil.EmptyArray<string>(); }
 
 			Dictionary<string, bool> d = new Dictionary<string, bool>();
 
@@ -1769,7 +1587,7 @@ namespace KeePassLib
 			}
 			catch(Exception) { Debug.Assert(false); }
 
-			return new string[0];
+			return MemUtil.EmptyArray<string>();
 		}
 	}
 
