@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -276,18 +276,16 @@ namespace KeePassLib.Security
 				return;
 			}
 
-			byte[] pbKey32 = g_pbKey32;
-			if(pbKey32 == null)
+			byte[] pbKey = g_pbKey32;
+			if(pbKey == null)
 			{
-				pbKey32 = GetRandom32();
-
-				byte[] pbUpd = Interlocked.Exchange<byte[]>(ref g_pbKey32, pbKey32);
-				if(pbUpd != null) pbKey32 = pbUpd;
+				Interlocked.CompareExchange<byte[]>(ref g_pbKey32, GetRandom32(), null);
+				pbKey = g_pbKey32;
 			}
 
 			byte[] pbIV = new byte[12];
-			MemUtil.UInt64ToBytesEx((ulong)m_lID, pbIV, 4);
-			using(ChaCha20Cipher c = new ChaCha20Cipher(pbKey32, pbIV, true))
+			MemUtil.Int64ToBytesEx(m_lID, pbIV, 4);
+			using(ChaCha20Cipher c = new ChaCha20Cipher(pbKey, pbIV, true))
 			{
 				c.Encrypt(m_pbData, 0, m_pbData.Length);
 			}
@@ -303,7 +301,7 @@ namespace KeePassLib.Security
 			else if(m_mp == PbMemProt.ChaCha20)
 			{
 				byte[] pbIV = new byte[12];
-				MemUtil.UInt64ToBytesEx((ulong)m_lID, pbIV, 4);
+				MemUtil.Int64ToBytesEx(m_lID, pbIV, 4);
 				using(ChaCha20Cipher c = new ChaCha20Cipher(g_pbKey32, pbIV, true))
 				{
 					c.Decrypt(m_pbData, 0, m_pbData.Length);
@@ -360,22 +358,21 @@ namespace KeePassLib.Security
 			return pbData;
 		}
 
-		private int? m_hash = null;
+		private int? m_oiHash = null;
 		public override int GetHashCode()
 		{
-			if(m_hash.HasValue) return m_hash.Value;
-
-			int h = (m_bProtected ? 0x7B11D289 : 0);
+			lock(m_objSync) { if(m_oiHash.HasValue) return m_oiHash.Value; }
 
 			byte[] pb = ReadData();
-			unchecked
-			{
-				for(int i = 0; i < pb.Length; ++i)
-					h = (h << 3) + h + (int)pb[i];
-			}
-			if(m_bProtected) MemUtil.ZeroByteArray(pb);
+			int h = (int)MemUtil.Hash32(pb, 0, pb.Length);
 
-			m_hash = h;
+			if(m_bProtected)
+			{
+				h ^= 0x57851B93;
+				MemUtil.ZeroByteArray(pb);
+			}
+
+			lock(m_objSync) { m_oiHash = h; }
 			return h;
 		}
 
