@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ namespace KeePassLib.Serialization
 {
 	public sealed class BinaryReaderEx
 	{
-		private Stream m_s;
+		private readonly Stream m_s;
 		// private Encoding m_enc; // See constructor
 
 		private string m_strReadExcp; // May be null
@@ -50,8 +50,7 @@ namespace KeePassLib.Serialization
 			set { m_sCopyTo = value; }
 		}
 
-		public BinaryReaderEx(Stream input, Encoding encoding,
-			string strReadExceptionText)
+		public BinaryReaderEx(Stream input, Encoding _, string strReadExceptionText)
 		{
 			if(input == null) throw new ArgumentNullException("input");
 
@@ -62,25 +61,24 @@ namespace KeePassLib.Serialization
 
 		public byte[] ReadBytes(int nCount)
 		{
-			try
-			{
-				byte[] pb = MemUtil.Read(m_s, nCount);
-				if((pb == null) || (pb.Length != nCount))
-				{
-					if(!string.IsNullOrEmpty(m_strReadExcp))
-						throw new EndOfStreamException(m_strReadExcp);
-					else throw new EndOfStreamException();
-				}
-
-				if(m_sCopyTo != null) m_sCopyTo.Write(pb, 0, pb.Length);
-				return pb;
-			}
+			byte[] pb;
+			try { pb = MemUtil.Read(m_s, nCount); }
 			catch(Exception)
 			{
 				if(!string.IsNullOrEmpty(m_strReadExcp))
 					throw new IOException(m_strReadExcp);
-				else throw;
+				throw;
 			}
+
+			if((pb == null) || (pb.Length != nCount))
+			{
+				if(!string.IsNullOrEmpty(m_strReadExcp))
+					throw new EndOfStreamException(m_strReadExcp);
+				throw new EndOfStreamException();
+			}
+
+			if(m_sCopyTo != null) m_sCopyTo.Write(pb, 0, pb.Length);
+			return pb;
 		}
 
 		public byte ReadByte()
