@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -40,19 +40,19 @@ namespace KeePassLib.Serialization
 {
 	public sealed class FileTransactionEx : IDisposable
 	{
-		private bool m_bTransacted;
+		private readonly bool m_bTransacted;
 		private IOConnectionInfo m_iocBase; // Null means disposed
 		private IOConnectionInfo m_iocTemp;
 		private IOConnectionInfo m_iocTxfMidFallback = null; // Null <=> TxF not used
 
 		private bool m_bMadeUnhidden = false;
-		private List<IOConnectionInfo> m_lToDelete = new List<IOConnectionInfo>();
+		private readonly List<IOConnectionInfo> m_lToDelete = new List<IOConnectionInfo>();
 
 		internal const string StrTempSuffix = ".tmp";
 		private static readonly string StrTxfTempPrefix = PwDefs.ShortProductName + "_TxF_";
 		internal const string StrTxfTempSuffix = ".tmp";
 
-		private static Dictionary<string, bool> g_dEnabled =
+		private static readonly Dictionary<string, bool> g_dEnabled =
 			new Dictionary<string, bool>(StrUtil.CaseIgnoreComparer);
 
 		private static bool g_bExtraSafe = false;
@@ -472,7 +472,7 @@ namespace KeePassLib.Serialization
 					"Software\\Microsoft\\OneDrive\\Accounts", false))
 				{
 					string[] vAccs = (((kAccs != null) ? kAccs.GetSubKeyNames() :
-						null) ?? new string[0]);
+						null) ?? MemUtil.EmptyArray<string>());
 
 					foreach(string strAcc in vAccs)
 					{
@@ -482,7 +482,7 @@ namespace KeePassLib.Serialization
 							strAcc + "\\Tenants", false))
 						{
 							string[] vTenants = (((kTenants != null) ?
-								kTenants.GetSubKeyNames() : null) ?? new string[0]);
+								kTenants.GetSubKeyNames() : null) ?? MemUtil.EmptyArray<string>());
 
 							foreach(string strT in vTenants)
 							{
@@ -491,7 +491,7 @@ namespace KeePassLib.Serialization
 								using(RegistryKey kT = kTenants.OpenSubKey(strT, false))
 								{
 									string[] vPaths = (((kT != null) ?
-										kT.GetValueNames() : null) ?? new string[0]);
+										kT.GetValueNames() : null) ?? MemUtil.EmptyArray<string>());
 
 									foreach(string strPath in vPaths)
 									{
