@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ namespace KeePassLib.Serialization
 			}
 		}
 
-		private List<string> m_lProtocols = new List<string>();
+		private readonly List<string> m_lProtocols = new List<string>();
 		public IEnumerable<string> Protocols
 		{
 			get { return m_lProtocols; }
