@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,12 +24,6 @@ using System.Globalization;
 using System.IO;
 using System.Security;
 using System.Text;
-using System.Xml;
-
-#if !KeePassUAP
-using System.Drawing;
-using System.Security.Cryptography;
-#endif
 
 #if KeePassLibSD
 using KeePassLibSD;
@@ -90,16 +84,14 @@ namespace KeePassLib.Serialization
 			m_xmlWriter = null;
 
 			PwGroup pgRoot = (pgDataSource ?? m_pwDatabase.RootGroup);
-			UTF8Encoding encNoBom = StrUtil.Utf8;
 			CryptoRandom cr = CryptoRandom.Instance;
 			byte[] pbCipherKey = null;
 			byte[] pbHmacKey64 = null;
 
-			m_pbsBinaries.Clear();
+			m_pbsBinaries = new ProtectedBinarySet(true);
 			m_pbsBinaries.AddFrom(pgRoot);
 
-			List<Stream> lStreams = new List<Stream>();
-			lStreams.Add(sSaveTo);
+			List<Stream> lStreams = new List<Stream> { sSaveTo };
 
 			HashingStreamEx sHashing = new HashingStreamEx(sSaveTo, true, null);
 			lStreams.Add(sHashing);
@@ -249,11 +241,8 @@ namespace KeePassLib.Serialization
 
 				WriteHeaderField(ms, KdbxHeaderFieldID.CipherID,
 					m_pwDatabase.DataCipherUuid.UuidBytes);
-
-				int nCprID = (int)m_pwDatabase.Compression;
 				WriteHeaderField(ms, KdbxHeaderFieldID.CompressionFlags,
-					MemUtil.UInt32ToBytes((uint)nCprID));
-
+					MemUtil.UInt32ToBytes((uint)m_pwDatabase.Compression));
 				WriteHeaderField(ms, KdbxHeaderFieldID.MasterSeed, m_pbMasterSeed);
 
 				if(m_uFileVersion < FileVersion32_4)
@@ -277,13 +266,10 @@ namespace KeePassLib.Serialization
 				{
 					WriteHeaderField(ms, KdbxHeaderFieldID.InnerRandomStreamKey,
 						m_pbInnerRandomStreamKey);
-
 					WriteHeaderField(ms, KdbxHeaderFieldID.StreamStartBytes,
 						m_pbStreamStartBytes);
-
-					int nIrsID = (int)m_craInnerRandomStream;
 					WriteHeaderField(ms, KdbxHeaderFieldID.InnerRandomStreamID,
-						MemUtil.Int32ToBytes(nIrsID));
+						MemUtil.Int32ToBytes((int)m_craInnerRandomStream));
 				}
 
 				// Write public custom data only when there is at least one item,
@@ -328,10 +314,8 @@ namespace KeePassLib.Serialization
 
 		private void WriteInnerHeader(Stream s)
 		{
-			int nIrsID = (int)m_craInnerRandomStream;
 			WriteInnerHeaderField(s, KdbxInnerHeaderFieldID.InnerRandomStreamID,
-				MemUtil.Int32ToBytes(nIrsID), null);
-
+				MemUtil.Int32ToBytes((int)m_craInnerRandomStream), null);
 			WriteInnerHeaderField(s, KdbxInnerHeaderFieldID.InnerRandomStreamKey,
 				m_pbInnerRandomStreamKey, null);
 
@@ -514,10 +498,20 @@ namespace KeePassLib.Serialization
 			WriteList(ElemTimes, pg);
 			WriteObject(ElemIsExpanded, pg.IsExpanded);
 			WriteObject(ElemGroupDefaultAutoTypeSeq, pg.DefaultAutoTypeSequence, true);
-			WriteObject(ElemEnableAutoType, StrUtil.BoolToStringEx(pg.EnableAutoType), false);
-			WriteObject(ElemEnableSearching, StrUtil.BoolToStringEx(pg.EnableSearching), false);
+			WriteObject(ElemEnableAutoType, pg.EnableAutoType);
+			WriteObject(ElemEnableSearching, pg.EnableSearching);
 			WriteObject(ElemLastTopVisibleEntry, pg.LastTopVisibleEntry);
 
+			if(m_uFileVersion >= FileVersion32_4_1)
+			{
+				if(!pg.PreviousParentGroup.Equals(PwUuid.Zero))
+					WriteObject(ElemPreviousParentGroup, pg.PreviousParentGroup);
+
+				List<string> lTags = pg.Tags;
+				if(lTags.Count != 0)
+					WriteObject(ElemTags, StrUtil.TagsToString(lTags, false), true);
+			}
+
 			if(pg.CustomData.Count > 0)
 				WriteList(ElemCustomData, pg.CustomData);
 		}
@@ -542,8 +536,16 @@ namespace KeePassLib.Serialization
 			WriteObject(ElemFgColor, StrUtil.ColorToUnnamedHtml(pe.ForegroundColor, true), false);
 			WriteObject(ElemBgColor, StrUtil.ColorToUnnamedHtml(pe.BackgroundColor, true), false);
 			WriteObject(ElemOverrideUrl, pe.OverrideUrl, true);
+
+			if((m_uFileVersion >= FileVersion32_4_1) && !pe.QualityCheck)
+				WriteObject(ElemQualityCheck, false);
+
 			WriteObject(ElemTags, StrUtil.TagsToString(pe.Tags, false), true);
 
+			if((m_uFileVersion >= FileVersion32_4_1) &&
+				!pe.PreviousParentGroup.Equals(PwUuid.Zero))
+				WriteObject(ElemPreviousParentGroup, pe.PreviousParentGroup);
+
 			WriteList(ElemTimes, pe);
 
 			WriteList(pe.Strings, true);
@@ -593,7 +595,7 @@ namespace KeePassLib.Serialization
 
 			foreach(AutoTypeAssociation a in cfgAutoType.Associations)
 				WriteObject(ElemAutoTypeItem, ElemWindow, ElemKeystrokeSequence,
-					new KeyValuePair<string, string>(a.WindowName, a.Sequence));
+					new KeyValuePair<string, string>(a.WindowName, a.Sequence), null);
 
 			m_xmlWriter.WriteEndElement();
 		}
@@ -613,7 +615,7 @@ namespace KeePassLib.Serialization
 			WriteObject(ElemUsageCount, times.UsageCount);
 			WriteObject(ElemLocationChanged, times.LocationChanged);
 
-			m_xmlWriter.WriteEndElement(); // Name
+			m_xmlWriter.WriteEndElement();
 		}
 
 		private void WriteList(string name, PwObjectList<PwEntry> value, bool bIsHistory)
@@ -667,7 +669,13 @@ namespace KeePassLib.Serialization
 			m_xmlWriter.WriteStartElement(name);
 
 			foreach(KeyValuePair<string, string> kvp in value)
-				WriteObject(ElemStringDictExItem, ElemKey, ElemValue, kvp);
+			{
+				DateTime? odtLastMod = null;
+				if(m_uFileVersion >= FileVersion32_4_1)
+					odtLastMod = value.GetLastModificationTime(kvp.Key);
+
+				WriteObject(ElemStringDictExItem, ElemKey, ElemValue, kvp, odtLastMod);
+			}
 
 			m_xmlWriter.WriteEndElement();
 		}
@@ -678,15 +686,23 @@ namespace KeePassLib.Serialization
 
 			m_xmlWriter.WriteStartElement(ElemCustomIcons);
 
-			foreach(PwCustomIcon pwci in m_pwDatabase.CustomIcons)
+			foreach(PwCustomIcon ci in m_pwDatabase.CustomIcons)
 			{
 				m_xmlWriter.WriteStartElement(ElemCustomIconItem);
 
-				WriteObject(ElemCustomIconItemID, pwci.Uuid);
+				WriteObject(ElemCustomIconItemID, ci.Uuid);
 
-				string strData = Convert.ToBase64String(pwci.ImageDataPng);
+				string strData = Convert.ToBase64String(ci.ImageDataPng);
 				WriteObject(ElemCustomIconItemData, strData, false);
 
+				if(m_uFileVersion >= FileVersion32_4_1)
+				{
+					if(ci.Name.Length != 0)
+						WriteObject(ElemName, ci.Name, true);
+					if(ci.LastModificationTime.HasValue)
+						WriteObject(ElemLastModTime, ci.LastModificationTime.Value);
+				}
+
 				m_xmlWriter.WriteEndElement();
 			}
 
@@ -710,9 +726,13 @@ namespace KeePassLib.Serialization
 
 		private void WriteObject(string name, bool value)
 		{
-			Debug.Assert(name != null);
+			WriteObject(name, (value ? ValTrue : ValFalse), false);
+		}
 
-			WriteObject(name, value ? ValTrue : ValFalse, false);
+		private void WriteObject(string name, bool? value)
+		{
+			if(!value.HasValue) WriteObject(name, ValNull, false);
+			else WriteObject(name, (value.Value ? ValTrue : ValFalse), false);
 		}
 
 		private void WriteObject(string name, PwUuid value)
@@ -786,18 +806,22 @@ namespace KeePassLib.Serialization
 			else WriteObject(name, TimeUtil.SerializeUtc(value), false);
 		}
 
-		private void WriteObject(string name, string strKeyName,
-			string strValueName, KeyValuePair<string, string> kvp)
+		private void WriteObject(string name, string strKeyName, string strValueName,
+			KeyValuePair<string, string> kvp, DateTime? odtLastMod)
 		{
 			m_xmlWriter.WriteStartElement(name);
 
 			m_xmlWriter.WriteStartElement(strKeyName);
 			m_xmlWriter.WriteString(StrUtil.SafeXmlString(kvp.Key));
 			m_xmlWriter.WriteEndElement();
+
 			m_xmlWriter.WriteStartElement(strValueName);
 			m_xmlWriter.WriteString(StrUtil.SafeXmlString(kvp.Value));
 			m_xmlWriter.WriteEndElement();
 
+			if(odtLastMod.HasValue)
+				WriteObject(ElemLastModTime, odtLastMod.Value);
+
 			m_xmlWriter.WriteEndElement();
 		}
 
