@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -336,8 +336,7 @@ namespace KeePassLib.Translation
 			byte[] pbSha = CryptoUtil.HashSha256(pb);
 
 			// See also MatchHash
-			return "v1:" + Convert.ToBase64String(pbSha, 0, 3,
-				Base64FormattingOptions.None);
+			return ("v1:" + Convert.ToBase64String(pbSha, 0, 3));
 		}
 
 		private static void WriteControlDependentParams(StringBuilder sb, Control c)
