@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,15 +21,17 @@ using System;
 using System.Collections.Generic;
 using System.Diagnostics;
 using System.IO;
-using System.IO.Compression;
 using System.Text;
 using System.Windows.Forms;
 using System.Xml;
 
+using KeePass.Util;
+
 using KeePassLib.Utility;
 
 using TrlUtil.App;
 using TrlUtil.App.Configuration;
+using TrlUtil.Native;
 
 namespace TrlUtil
 {
@@ -50,11 +52,12 @@ namespace TrlUtil
 		{
 			try
 			{
+				ConfigureDpi();
 				Application.EnableVisualStyles();
 				Application.SetCompatibleTextRenderingDefault(false);
 
 				KeePass.Program.EnableTranslation = false; // We need English
-				if(!KeePass.Program.CommonInit()) return;
+				KeePass.Program.CommonInitialize();
 
 				m_cfg = (TceConfig.Load() ?? new TceConfig());
 
@@ -63,7 +66,7 @@ namespace TrlUtil
 			catch(Exception ex)
 			{
 				MessageBox.Show(ex.Message, TuDefs.ProductName,
-					MessageBoxButtons.OK, MessageBoxIcon.Warning);
+					MessageBoxButtons.OK, MessageBoxIcon.Error);
 			}
 
 			TceConfig.Save(m_cfg);
@@ -83,6 +86,23 @@ namespace TrlUtil
 			Application.Run(new MainForm());
 		}
 
+		private static void ConfigureDpi()
+		{
+			// Ensure that base hashes are computed with respect to 100% DPI
+			try
+			{
+				if(WinUtil.IsAtLeastWindows10) // 8.1 partially
+				{
+					if(NativeMethods.SetProcessDpiAwareness(
+						NativeMethods.ProcessDpiAwareness.Unaware) < 0)
+					{
+						Debug.Assert(false);
+					}
+				}
+			}
+			catch(Exception) { Debug.Assert(false); }
+		}
+
 		private static void ExecuteCmd(string strCmd, string strFile)
 		{
 			if(strCmd == "convert_resx")
