@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -113,7 +113,7 @@ namespace KeePass.UI
 			this.AutoWordSelection = false;
 		}
 
-		private CriticalSectionEx m_csAutoProps = new CriticalSectionEx();
+		private readonly CriticalSectionEx m_csAutoProps = new CriticalSectionEx();
 		protected override void OnHandleCreated(EventArgs e)
 		{
 			base.OnHandleCreated(e);
