@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ namespace KeePass.UI
 {
 	public sealed class CustomToolStripEx : ToolStrip
 	{
-		private CriticalSectionEx m_csSizeAuto = new CriticalSectionEx();
+		private readonly CriticalSectionEx m_csSizeAuto = new CriticalSectionEx();
 		private int m_iLockedHeight = 0;
 
 		public CustomToolStripEx() : base()
