@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -52,10 +52,7 @@ namespace KeePass.UI.ToolStripRendering
 			TsrFactory f81 = new Win81TsrFactory();
 			TsrFactory f10 = new Win10TsrFactory();
 			TsrFactory fP = new ProExtTsrFactory();
-
-			TsrFactory fS;
-			try { fS = new SystemTsrFactory(); }
-			catch(Exception) { Debug.Assert(false); fS = fP; }
+			TsrFactory fS = new SystemTsrFactory();
 
 			// https://sourceforge.net/p/keepass/discussion/329220/thread/fab85f1d/
 			// https://keepass.info/help/kb/tsrstyles_survey.html
