@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
-using System.IO;
 using System.Diagnostics;
+using System.IO;
+using System.Text;
 
 using KeePassLib.Utility;
 
@@ -32,7 +32,7 @@ namespace KeePass.Util.Archive
 		private const ulong g_uSig = 0x562CBA7C4F9AF297UL;
 		private const ushort g_uVer = 1;
 
-		private Dictionary<string, byte[]> m_dItems =
+		private readonly Dictionary<string, byte[]> m_dItems =
 			new Dictionary<string, byte[]>();
 		public IDictionary<string, byte[]> Items
 		{
@@ -48,7 +48,6 @@ namespace KeePass.Util.Archive
 			try
 			{
 				string strExe = WinUtil.GetExecutable();
-
 				string strFile = UrlUtil.MakeAbsolutePath(strExe, strXspFile);
 
 				string strDir = UrlUtil.EnsureTerminatingSeparator(
@@ -59,10 +58,7 @@ namespace KeePass.Util.Archive
 
 				CreateFilePriv(strFile, strDir);
 			}
-			catch(Exception ex)
-			{
-				MessageService.ShowWarningExcp(ex);
-			}
+			catch(Exception ex) { MessageService.ShowWarningExcp(ex); }
 		}
 
 		private static void CreateFilePriv(string strFile, string strSourceDir)
