@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -35,9 +35,9 @@ using KeePass.UI;
 using KeePass.Util.Spr;
 
 using KeePassLib;
-using KeePassLib.Security;
 using KeePassLib.Collections;
 using KeePassLib.Delegates;
+using KeePassLib.Resources;
 using KeePassLib.Utility;
 
 using NativeLib = KeePassLib.Native.NativeLib;
@@ -99,15 +99,15 @@ namespace KeePass.Util
 
 		internal static void InitStatic()
 		{
-			try
-			{
-				// SendKeys is not used anymore, thus the following is
-				// not required:
-				// // Enable new SendInput method; see
-				// // https://msdn.microsoft.com/en-us/library/system.windows.forms.sendkeys.aspx
-				// ConfigurationManager.AppSettings.Set("SendKeys", "SendInput");
-			}
-			catch(Exception) { Debug.Assert(false); }
+			// try
+			// {
+			//	// SendKeys is not used anymore, thus the following is
+			//	// not required:
+			//	// Enable new SendInput method; see
+			//	// https://msdn.microsoft.com/en-us/library/system.windows.forms.sendkeys.aspx
+			//	ConfigurationManager.AppSettings.Set("SendKeys", "SendInput");
+			// }
+			// catch(Exception) { Debug.Assert(false); }
 		}
 
 		internal static bool IsMatchWindow(string strWindow, string strFilter)
@@ -184,8 +184,7 @@ namespace KeePass.Util
 			// string strError = ValidateAutoTypeSequence(args.Sequence);
 			// if(!string.IsNullOrEmpty(strError))
 			// {
-			//	MessageService.ShowWarning(args.Sequence +
-			//		MessageService.NewParagraph + strError);
+			//	MessageService.ShowWarning(args.Sequence, strError);
 			//	return false;
 			// }
 
@@ -194,20 +193,16 @@ namespace KeePass.Util
 			if(AutoType.FilterSendPre != null) AutoType.FilterSendPre(null, args);
 			if(AutoType.FilterSend != null) AutoType.FilterSend(null, args);
 
-			if(args.Sequence.Length > 0)
+			if(args.Sequence.Length != 0)
 			{
-				string strError = null;
-				try { SendInputEx.SendKeysWait(args.Sequence, args.SendObfuscated); }
-				catch(SecurityException exSec) { strError = exSec.Message; }
-				catch(Exception ex)
-				{
-					strError = args.Sequence + MessageService.NewParagraph +
-						ex.Message;
-				}
+				string strSeqR = args.Sequence;
+				Exception exR = null;
+				try { SendInputEx.SendKeysWait(strSeqR, args.SendObfuscated); }
+				catch(Exception ex) { exR = ex; }
 
 				if(AutoType.SendPost != null) AutoType.SendPost(null, args);
 
-				if(!string.IsNullOrEmpty(strError))
+				if(exR != null)
 				{
 					try
 					{
@@ -217,7 +212,9 @@ namespace KeePass.Util
 					}
 					catch(Exception) { Debug.Assert(false); }
 
-					MessageService.ShowWarning(strError);
+					if(!PwDefs.DebugMode || !AppPolicy.Current.UnhidePasswords)
+						strSeqR = null;
+					MessageService.ShowWarning(strSeqR, exR);
 				}
 			}
 
@@ -349,7 +346,7 @@ namespace KeePass.Util
 
 			if(Program.Config.Integration.AutoTypeMatchByTagInTitle)
 			{
-				foreach(string strTag in pwe.Tags)
+				foreach(string strTag in pwe.GetTagsInherited())
 				{
 					if(IsMatchSub(strWindow, strTag))
 					{
@@ -395,8 +392,8 @@ namespace KeePass.Util
 			lSeq.Add(strSeq); // Non-canonical version
 		}
 
-		private const string StrBraceOpen = @"{1E1F63AB-2F63-4B60-ADBA-7F38B8D7778E}";
-		private const string StrBraceClose = @"{34D698D7-CEBF-4AF0-87BF-DC1B1F5E95A0}";
+		private const string StrBraceOpen = "1E1F63AB-2F63-4B60-ADBA-7F38B8D7778E";
+		private const string StrBraceClose = "34D698D7-CEBF-4AF0-87BF-DC1B1F5E95A0";
 		private static string CanonicalizeSeq(string strSeq)
 		{
 			// Preprocessing: balance braces
@@ -566,7 +563,7 @@ namespace KeePass.Util
 			if(!pe.GetAutoTypeEnabled()) return false;
 			if(!AppPolicy.Try(AppPolicyId.AutoTypeWithoutContext)) return false;
 
-			bool bTopMost = ((fCurrent != null) ? fCurrent.TopMost : false);
+			bool bTopMost = ((fCurrent != null) && fCurrent.TopMost);
 			if(bTopMost) fCurrent.TopMost = false;
 
 			try
@@ -637,8 +634,8 @@ namespace KeePass.Util
 			Debug.Assert(strSequence != null);
 
 			string strSeq = strSequence;
-			strSeq = strSeq.Replace(@"{{}", string.Empty);
-			strSeq = strSeq.Replace(@"{}}", string.Empty);
+			strSeq = strSeq.Replace("{{}", string.Empty);
+			strSeq = strSeq.Replace("{}}", string.Empty);
 
 			int cBrackets = 0;
 			for(int c = 0; c < strSeq.Length; ++c)
@@ -651,7 +648,7 @@ namespace KeePass.Util
 			}
 			if(cBrackets != 0) return KPRes.AutoTypeSequenceInvalid;
 
-			if(strSeq.IndexOf(@"{}") >= 0) return KPRes.AutoTypeSequenceInvalid;
+			if(strSeq.IndexOf("{}") >= 0) return KPRes.AutoTypeSequenceInvalid;
 
 			try
 			{
@@ -661,12 +658,12 @@ namespace KeePass.Util
 				foreach(Match m in matches)
 				{
 					string strValue = m.Value;
-					if(strValue.StartsWith(@"{s:", StrUtil.CaseIgnoreCmp))
+					if(strValue.StartsWith("{S:", StrUtil.CaseIgnoreCmp))
 						return (KPRes.AutoTypeUnknownPlaceholder +
 							MessageService.NewLine + strValue);
 				}
 			}
-			catch(Exception ex) { Debug.Assert(false); return ex.Message; }
+			catch(Exception ex) { Debug.Assert(false); return StrUtil.FormatException(ex, null); }
 
 			return null;
 		} */
@@ -713,5 +710,66 @@ namespace KeePass.Util
 
 			strWindow = NormalizeWindowText(strWindow);
 		}
+
+		// Cf. PwEntry.GetAutoTypeEnabled
+		internal static string GetEnabledText(PwEntry pe, out object oBlocker)
+		{
+			oBlocker = null;
+			if(pe == null) { Debug.Assert(false); return string.Empty; }
+
+			if(!pe.AutoType.Enabled)
+			{
+				oBlocker = pe;
+				return (KPRes.No + " (" + KLRes.EntryLower + ")");
+			}
+
+			PwGroup pg = pe.ParentGroup;
+			while(pg != null)
+			{
+				if(pg.EnableAutoType.HasValue)
+				{
+					if(pg.EnableAutoType.Value) break;
+
+					oBlocker = pg;
+					return (KPRes.No + " (" + KLRes.GroupLower + " '" + pg.Name + "')");
+				}
+
+				pg = pg.ParentGroup;
+			}
+
+			// Options like 'Expired entries can match' influence the global
+			// auto-type matching only, not commands like 'Perform Auto-Type'
+
+			return KPRes.Yes;
+		}
+
+		internal static string GetSequencesText(PwEntry pe)
+		{
+			if(pe == null) { Debug.Assert(false); return string.Empty; }
+
+			string strSeq = pe.GetAutoTypeSequence();
+			Debug.Assert(strSeq.Length != 0);
+			string str = ((strSeq.Length != 0) ? strSeq : ("(" + KPRes.Empty + ")"));
+
+			int cAssoc = pe.AutoType.AssociationsCount;
+			if(cAssoc != 0)
+			{
+				Dictionary<string, bool> d = new Dictionary<string, bool>();
+				d[strSeq] = true;
+
+				foreach(AutoTypeAssociation a in pe.AutoType.Associations)
+				{
+					string strAssocSeq = a.Sequence;
+					if(strAssocSeq.Length != 0) d[strAssocSeq] = true;
+				}
+
+				int c = d.Count;
+				str += ((c >= 2) ? (" " + KPRes.MoreAnd.Replace(@"{PARAM}",
+					(c - 1).ToString())) : string.Empty) + " (" +
+					cAssoc.ToString() + " " + KPRes.AssociationsLower + ")";
+			}
+
+			return str;
+		}
 	}
 }
