@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,8 +19,8 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
 using System.Diagnostics;
+using System.Text;
 
 using KeePass.Util.Spr;
 
@@ -136,7 +136,7 @@ namespace KeePass.Util
 			get { return m_pd; }
 		}
 
-		private List<string> m_lSeqs = new List<string>();
+		private readonly List<string> m_lSeqs = new List<string>();
 		internal IEnumerable<string> Sequences
 		{
 			get { return m_lSeqs; }
