@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
 
 using System;
 using System.Collections.Generic;
+using System.Diagnostics;
 using System.Text;
 using System.Windows.Forms;
-using System.Diagnostics;
 
 using KeePass.Resources;
 using KeePass.UI;
@@ -37,14 +37,14 @@ namespace KeePass.Util
 
 		public static void Show()
 		{
-			EntryMenu.Show(Cursor.Position.X, Cursor.Position.Y);
+			Show(Cursor.Position.X, Cursor.Position.Y);
 		}
 
 		public static void Show(int iPosX, int iPosY)
 		{
-			EntryMenu.Destroy();
+			Destroy();
 
-			m_ctx = EntryMenu.Construct();
+			m_ctx = Construct();
 			m_ctx.Show(iPosX, iPosY);
 		}
 
@@ -85,7 +85,6 @@ namespace KeePass.Util
 				}
 			}
 
-			GlobalWindowManager.CustomizeControl(ctx);
 			return ctx;
 		}
 
