@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@ using System.Windows.Forms;
 
 using KeePass.Forms;
 using KeePass.Resources;
+using KeePass.UI;
 
 using KeePassLib;
 using KeePassLib.Delegates;
@@ -35,10 +36,10 @@ namespace KeePass.Util
 {
 	public sealed class TemplateEntryEventArgs : EventArgs
 	{
-		private PwEntry m_peTemplate;
+		private readonly PwEntry m_peTemplate;
 		public PwEntry TemplateEntry { get { return m_peTemplate; } }
 
-		private PwEntry m_pe;
+		private readonly PwEntry m_pe;
 		public PwEntry Entry { get { return m_pe; } }
 
 		public TemplateEntryEventArgs(PwEntry peTemplate, PwEntry pe)
@@ -51,7 +52,7 @@ namespace KeePass.Util
 	public static class EntryTemplates
 	{
 		private static ToolStripDropDownItem g_tsiHost = null;
-		private static List<ToolStripItem> g_lTopLevelItems = new List<ToolStripItem>();
+		private static readonly List<ToolStripItem> g_lTopLevelItems = new List<ToolStripItem>();
 
 		public static event EventHandler<TemplateEntryEventArgs> EntryCreating;
 		public static event EventHandler<TemplateEntryEventArgs> EntryCreated;
@@ -195,9 +196,11 @@ namespace KeePass.Util
 				return l;
 			}
 
+			AccessKeyManagerEx ak = new AccessKeyManagerEx();
+
 			foreach(PwGroup pgSub in pg.Groups)
 			{
-				string strText = StrUtil.EncodeMenuText(pgSub.Name);
+				string strText = ak.CreateText(pgSub.Name, true);
 				ToolStripMenuItem tsmi = new ToolStripMenuItem(strText);
 				tsmi.Image = GetImage(pgSub.IconId, pgSub.CustomIconUuid);
 				tsmi.Tag = pgSub;
@@ -231,8 +234,8 @@ namespace KeePass.Util
 
 			foreach(PwEntry pe in pg.Entries)
 			{
-				string strText = StrUtil.EncodeMenuText(pe.Strings.ReadSafe(
-					PwDefs.TitleField));
+				string strText = ak.CreateText(pe.Strings.ReadSafe(
+					PwDefs.TitleField), true);
 				ToolStripMenuItem tsmi = new ToolStripMenuItem(strText);
 				tsmi.Image = GetImage(pe.IconId, pe.CustomIconUuid);
 				tsmi.Tag = pe;
