@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ using System.Collections.Generic;
 using System.Diagnostics;
 using System.Text;
 
+using KeePass.App.Configuration;
 using KeePass.Resources;
 
 #if !KeePassUAP
@@ -37,49 +38,52 @@ namespace KeePass.Util
 {
 	public static class PwGeneratorUtil
 	{
-		private static string m_strBuiltInSuffix = null;
+		private static string g_strBuiltInSuffix = null;
 		internal static string BuiltInSuffix
 		{
 			get
 			{
-				if(m_strBuiltInSuffix == null)
-					m_strBuiltInSuffix = " (" + KPRes.BuiltIn + ")";
-				return m_strBuiltInSuffix;
+				if(g_strBuiltInSuffix == null)
+					g_strBuiltInSuffix = " (" + KPRes.BuiltIn + ")";
+				return g_strBuiltInSuffix;
 			}
 		}
 
-		private static List<PwProfile> m_lBuiltIn = null;
+		private static List<PwProfile> g_lBuiltIn = null;
 		public static List<PwProfile> BuiltInProfiles
 		{
 			get
 			{
-				if(m_lBuiltIn == null) AllocStandardProfiles();
-				return m_lBuiltIn;
+				if(g_lBuiltIn == null) g_lBuiltIn = AllocStdProfiles();
+				return g_lBuiltIn;
 			}
 		}
 
-		private static void AllocStandardProfiles()
+		private static List<PwProfile> AllocStdProfiles()
 		{
-			m_lBuiltIn = new List<PwProfile>();
-
-			AddStdPattern(KPRes.RandomMacAddress, @"HH\-HH\-HH\-HH\-HH\-HH");
+			List<PwProfile> l = new List<PwProfile>();
 
 			string strHex = KPRes.HexKeyEx;
-			AddStdPattern(strHex.Replace(@"{PARAM}", "40"), @"h{10}");
-			AddStdPattern(strHex.Replace(@"{PARAM}", "128"), @"h{32}");
-			AddStdPattern(strHex.Replace(@"{PARAM}", "256"), @"h{64}");
+			AddStdPattern(l, strHex.Replace(@"{PARAM}", "40"), @"H{10}");
+			AddStdPattern(l, strHex.Replace(@"{PARAM}", "128"), @"H{32}");
+			AddStdPattern(l, strHex.Replace(@"{PARAM}", "256"), @"H{64}");
+
+			AddStdPattern(l, KPRes.MacAddress, "H\\2\\-HH\\-HH\\-HH\\-HH\\-HH");
+
+			return l;
 		}
 
-		private static void AddStdPattern(string strName, string strPattern)
+		private static void AddStdPattern(List<PwProfile> l, string strName,
+			string strPattern)
 		{
-			PwProfile p = new PwProfile();
+			PwProfile prf = new PwProfile();
 
-			p.Name = strName + PwGeneratorUtil.BuiltInSuffix;
-			p.CollectUserEntropy = false;
-			p.GeneratorType = PasswordGeneratorType.Pattern;
-			p.Pattern = strPattern;
+			prf.Name = strName + PwGeneratorUtil.BuiltInSuffix;
+			prf.GeneratorType = PasswordGeneratorType.Pattern;
+			prf.Pattern = strPattern;
+			prf.CollectUserEntropy = false;
 
-			m_lBuiltIn.Add(p);
+			l.Add(prf);
 		}
 
 		/// <summary>
@@ -91,7 +95,7 @@ namespace KeePass.Util
 			List<PwProfile> lUser = Program.Config.PasswordGenerator.UserProfiles;
 
 			// Sort it in the configuration file
-			if(bSort) lUser.Sort(PwGeneratorUtil.CompareProfilesByName);
+			if(bSort) SortProfiles(lUser);
 
 			// Remove old built-in profiles by KeePass <= 2.17
 			for(int i = lUser.Count - 1; i >= 0; --i)
@@ -102,7 +106,7 @@ namespace KeePass.Util
 			List<PwProfile> l = new List<PwProfile>();
 			l.AddRange(PwGeneratorUtil.BuiltInProfiles);
 			l.AddRange(lUser);
-			if(bSort) l.Sort(PwGeneratorUtil.CompareProfilesByName);
+			if(bSort) SortProfiles(l);
 			return l;
 		}
 
@@ -110,11 +114,12 @@ namespace KeePass.Util
 		{
 			if(strName == null) { Debug.Assert(false); return false; }
 
-			string strWithSuffix = strName + PwGeneratorUtil.BuiltInSuffix;
-			foreach(PwProfile p in PwGeneratorUtil.BuiltInProfiles)
+			string strNameS = strName + PwGeneratorUtil.BuiltInSuffix;
+
+			foreach(PwProfile prf in PwGeneratorUtil.BuiltInProfiles)
 			{
-				if(p.Name.Equals(strName, StrUtil.CaseIgnoreCmp) ||
-					p.Name.Equals(strWithSuffix, StrUtil.CaseIgnoreCmp))
+				if(prf.Name.Equals(strName, StrUtil.CaseIgnoreCmp) ||
+					prf.Name.Equals(strNameS, StrUtil.CaseIgnoreCmp))
 					return true;
 			}
 
@@ -130,6 +135,29 @@ namespace KeePass.Util
 			return StrUtil.CompareNaturally(a.Name, b.Name);
 		}
 
+		internal static void SortProfiles(List<PwProfile> l)
+		{
+			if(l == null) { Debug.Assert(false); return; }
+
+			l.Sort(PwGeneratorUtil.CompareProfilesByName);
+		}
+
+		internal static int FindProfile(List<PwProfile> l, string strName,
+			bool bIgnoreCase)
+		{
+			if(l == null) { Debug.Assert(false); return -1; }
+
+			StringComparison sc = (bIgnoreCase ? StrUtil.CaseIgnoreCmp :
+				StringComparison.Ordinal);
+
+			for(int i = 0; i < l.Count; ++i)
+			{
+				if(l[i].Name.Equals(strName, sc)) return i;
+			}
+
+			return -1;
+		}
+
 #if !KeePassUAP
 		internal static ProtectedString GenerateAcceptable(PwProfile prf,
 			byte[] pbUserEntropy, PwEntry peOptCtx, PwDatabase pdOptCtx,
@@ -176,15 +204,15 @@ namespace KeePass.Util
 
 				if(bAcceptAlways) break;
 
-				string str = ps.ReadString();
-				string strCmp = SprEngine.Compile(str, ctx);
+				char[] v = ps.ReadChars();
+				char[] vCmp = SprEngine.Compile(v, ctx);
 
-				if(str != strCmp)
+				if(!MemUtil.ArrayHelperExOfChar.Equals(v, vCmp))
 				{
 					if(prf.GeneratorType == PasswordGeneratorType.CharSet)
 						continue; // Silently try again
 
-					string strText = str + MessageService.NewParagraph +
+					string strText = (new string(v)) + MessageService.NewParagraph +
 						KPRes.GenPwSprVariant + MessageService.NewParagraph +
 						KPRes.GenPwAccept;
 
@@ -193,6 +221,8 @@ namespace KeePass.Util
 					bAcceptAlways = true;
 				}
 
+				MemUtil.ZeroArray<char>(v);
+				MemUtil.ZeroArray<char>(vCmp);
 				break;
 			}
 
@@ -207,12 +237,14 @@ namespace KeePass.Util
 
 		internal static void GenerateAuto(PwEntry pe, PwDatabase pd)
 		{
-			if(pe == null) { Debug.Assert(false); return; }
-			if(pd == null) { Debug.Assert(false); return; }
+			if((pe == null) || (pd == null)) { Debug.Assert(false); return; }
+
+			AcePasswordGenerator acePG = Program.Config.PasswordGenerator;
+			PwProfile prf = (acePG.ProfilesEnabled ?
+				acePG.AutoGeneratedPasswordsProfile : new PwProfile());
+
+			ProtectedString ps = GenerateAcceptable(prf, null, pe, pd, false);
 
-			ProtectedString ps = GenerateAcceptable(
-				Program.Config.PasswordGenerator.AutoGeneratedPasswordsProfile,
-				null, pe, pd, false);
 			pe.Strings.Set(PwDefs.PasswordField, ps.WithProtection(
 				pd.MemoryProtection.ProtectPassword));
 		}
