@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -163,7 +163,8 @@ namespace KeePass.Util.SendInputExt
 
 			if(g_vProcessNamesVMs == null)
 				g_vProcessNamesVMs = new string[] {
-					"MSTSC", // Remote Desktop Connection client
+					"MSTSC", // Remote Desktop Connection client (Windows)
+					"MSRDC", // Remote Desktop client (WSL)
 					"VirtualBox", // Oracle VirtualBox <= 5
 					"VirtualBoxVM", // Oracle VirtualBox >= 6
 					"VpxClient", // VMware vSphere client
