@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ namespace KeePass.Util
 	{
 		private static ShutdownBlocker g_sdbPrimary = null;
 #if DEBUG
-		internal static ShutdownBlocker Instance
+		internal static ShutdownBlocker PrimaryInstance
 		{
 			get { return g_sdbPrimary; }
 		}
