@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -45,8 +45,6 @@ namespace KeePass.Util.Spr
 		private const uint MaxRecursionDepth = 12;
 		private const StringComparison ScMethod = StringComparison.OrdinalIgnoreCase;
 
-		// private static readonly char[] m_vPlhEscapes = new char[] { '{', '}', '%' };
-
 		// Important notes for plugin developers subscribing to the following events:
 		// * If possible, prefer subscribing to FilterCompile instead of
 		//   FilterCompilePre.
@@ -64,11 +62,11 @@ namespace KeePass.Util.Spr
 		public static event EventHandler<SprEventArgs> FilterCompilePre;
 		public static event EventHandler<SprEventArgs> FilterCompile;
 
-		private static List<string> m_lFilterPlh = new List<string>();
+		private static readonly List<string> g_lFilterPlh = new List<string>();
 		// See the events above
 		public static List<string> FilterPlaceholderHints
 		{
-			get { return m_lFilterPlh; }
+			get { return g_lFilterPlh; }
 		}
 
 		[Obsolete]
@@ -84,12 +82,12 @@ namespace KeePass.Util.Spr
 		public static string Compile(string strText, SprContext ctx)
 		{
 			if(strText == null) { Debug.Assert(false); return string.Empty; }
-			if(strText.Length == 0) return string.Empty;
+			if(!MightChange(strText, ctx)) return strText;
 
 			if(ctx == null) ctx = new SprContext();
 			ctx.RefCache.Clear();
 
-			string str = SprEngine.CompileInternal(strText, ctx, 0);
+			string str = CompileInternal(strText, ctx, 0);
 
 			// if(bEscapeForAutoType && !bIsAutoTypeSequence)
 			//	str = SprEncoding.MakeAutoTypeSequence(str);
@@ -97,6 +95,14 @@ namespace KeePass.Util.Spr
 			return str;
 		}
 
+		internal static char[] Compile(char[] vText, SprContext ctx)
+		{
+			if(vText == null) { Debug.Assert(false); return MemUtil.EmptyArray<char>(); }
+			if(!MightChange(vText, ctx)) return vText;
+
+			return Compile(new string(vText), ctx).ToCharArray();
+		}
+
 		private static string CompileInternal(string strText, SprContext ctx,
 			uint uRecursionLevel)
 		{
@@ -122,7 +128,7 @@ namespace KeePass.Util.Spr
 			}
 
 			if((ctx.Flags & SprCompileFlags.Comments) != SprCompileFlags.None)
-				str = RemoveComments(str);
+				str = RemoveComments(str, null, null);
 
 			// The following realizes {T-CONV:/Text/Raw/}, which should be
 			// one of the first transformations (except comments)
@@ -276,7 +282,7 @@ namespace KeePass.Util.Spr
 					string strValue = (de.Value as string);
 					if(strValue == null) { Debug.Assert(false); strValue = string.Empty; }
 
-					str = Fill(str, @"%" + strKey + @"%", strValue, ctx, uRecursionLevel);
+					str = Fill(str, "%" + strKey + "%", strValue, ctx, uRecursionLevel);
 				}
 			}
 
@@ -502,20 +508,46 @@ namespace KeePass.Util.Spr
 			return str;
 		}
 
-		private const string StrRemStart = @"{C:";
-		private const string StrRemEnd = @"}";
-		private static string RemoveComments(string strSeq)
+		internal static string RemoveComments(string strSeq, List<string> lComments,
+			SprContext ctxComments)
 		{
+			if(strSeq == null) { Debug.Assert(false); return string.Empty; }
+
+			const string strStartP = @"{C:";
 			string str = strSeq;
+			int iOffsetP = 0;
 
-			while(true)
+			while(iOffsetP < str.Length)
 			{
-				int iStart = str.IndexOf(StrRemStart, SprEngine.ScMethod);
-				if(iStart < 0) break;
-				int iEnd = str.IndexOf(StrRemEnd, iStart + 1, SprEngine.ScMethod);
-				if(iEnd <= iStart) break;
+				int iStartP = str.IndexOf(strStartP, iOffsetP, SprEngine.ScMethod);
+				if(iStartP < 0) break;
 
-				str = (str.Substring(0, iStart) + str.Substring(iEnd + StrRemEnd.Length));
+				int iStartC = iStartP + strStartP.Length, cBraces = 1;
+
+				for(int iEndP = iStartC; iEndP < str.Length; ++iEndP)
+				{
+					char ch = str[iEndP];
+					if(ch == '{') ++cBraces;
+					else if(ch == '}')
+					{
+						if(--cBraces == 0)
+						{
+							if(lComments != null)
+							{
+								string strC = str.Substring(iStartC, iEndP - iStartC);
+								if(ctxComments != null)
+									strC = Compile(strC, ctxComments);
+								lComments.Add(strC);
+							}
+
+							str = str.Remove(iStartP, iEndP - iStartP + 1);
+							break;
+						}
+					}
+				}
+
+				if(cBraces != 0) break; // Malformed input; avoid infinite loop
+				iOffsetP = iStartP;
 			}
 
 			return str;
@@ -600,8 +632,8 @@ namespace KeePass.Util.Spr
 			if(strRef[1] != '@') return null;
 			if(strRef[3] != ':') return null;
 
-			chScan = char.ToUpper(strRef[2]);
-			chWanted = char.ToUpper(strRef[0]);
+			chScan = char.ToUpperInvariant(strRef[2]);
+			chWanted = char.ToUpperInvariant(strRef[0]);
 
 			SearchParameters sp = SearchParameters.None;
 			sp.SearchString = strRef.Substring(4);
@@ -622,50 +654,36 @@ namespace KeePass.Util.Spr
 			return ((lFound.UCount > 0) ? lFound.GetAt(0) : null);
 		}
 
-		// internal static bool MightChange(string strText)
-		// {
-		//	if(string.IsNullOrEmpty(strText)) return false;
-		//	return (strText.IndexOfAny(m_vPlhEscapes) >= 0);
-		// }
-
-		/* internal static bool MightChange(string str)
+		// Cf. char[] overload
+		internal static bool MightChange(string str, SprContext ctx)
 		{
 			if(str == null) { Debug.Assert(false); return false; }
+			if(str.Length == 0) return false;
 
-			int iBStart = str.IndexOf('{');
-			if(iBStart >= 0)
-			{
-				int iBEnd = str.LastIndexOf('}');
-				if(iBStart < iBEnd) return true;
-			}
+			int i = str.IndexOf('{');
+			if((i >= 0) && (i < str.LastIndexOf('}'))) return true;
 
-			int iPFirst = str.IndexOf('%');
-			if(iPFirst >= 0)
-			{
-				int iPLast = str.LastIndexOf('%');
-				if(iPFirst < iPLast) return true;
-			}
+			i = str.IndexOf('%');
+			if((i >= 0) && (i < str.LastIndexOf('%'))) return true;
+
+			if((ctx != null) && ctx.EncodeAsAutoTypeSequence) return true;
 
 			return false;
-		} */
+		}
 
-		internal static bool MightChange(char[] v)
+		// Cf. string overload
+		internal static bool MightChange(char[] v, SprContext ctx)
 		{
 			if(v == null) { Debug.Assert(false); return false; }
+			if(v.Length == 0) return false;
 
-			int iBStart = Array.IndexOf<char>(v, '{');
-			if(iBStart >= 0)
-			{
-				int iBEnd = Array.LastIndexOf<char>(v, '}');
-				if(iBStart < iBEnd) return true;
-			}
+			int i = Array.IndexOf<char>(v, '{');
+			if((i >= 0) && (i < Array.LastIndexOf<char>(v, '}'))) return true;
 
-			int iPFirst = Array.IndexOf<char>(v, '%');
-			if(iPFirst >= 0)
-			{
-				int iPLast = Array.LastIndexOf<char>(v, '%');
-				if(iPFirst < iPLast) return true;
-			}
+			i = Array.IndexOf<char>(v, '%');
+			if((i >= 0) && (i < Array.LastIndexOf<char>(v, '%'))) return true;
+
+			if((ctx != null) && ctx.EncodeAsAutoTypeSequence) return true;
 
 			return false;
 		}
@@ -676,8 +694,11 @@ namespace KeePass.Util.Spr
 		/// </summary>
 		internal static bool MightDeref(string strText)
 		{
-			if(strText == null) return false;
-			return (strText.IndexOf('{') >= 0);
+			if(strText == null) { Debug.Assert(false); return false; }
+			if(strText.Length == 0) return false;
+
+			int i = strText.IndexOf('{');
+			return ((i >= 0) && (i < strText.LastIndexOf('}')));
 		}
 
 		internal static string DerefFn(string str, PwEntry pe)
@@ -762,7 +783,7 @@ namespace KeePass.Util.Spr
 				try
 				{
 					string strNew = lParams[0];
-					string strCmd = lParams[1].ToLower();
+					string strCmd = lParams[1].ToLowerInvariant();
 
 					if((strCmd == "u") || (strCmd == "upper"))
 						strNew = strNew.ToUpper();
@@ -943,11 +964,7 @@ namespace KeePass.Util.Spr
 
 					if(bWait) p.WaitForExit();
 				}
-				catch(Exception ex)
-				{
-					string strMsg = strCmd + MessageService.NewParagraph + ex.Message;
-					MessageService.ShowWarning(strMsg);
-				}
+				catch(Exception ex) { MessageService.ShowWarning(strCmd, ex); }
 				finally
 				{
 					try { if(p != null) p.Dispose(); }
@@ -958,7 +975,7 @@ namespace KeePass.Util.Spr
 			return str;
 		}
 
-		private static Dictionary<string, string> SplitParams(string str)
+		internal static Dictionary<string, string> SplitParams(string str)
 		{
 			Dictionary<string, string> d = new Dictionary<string, string>();
 			if(string.IsNullOrEmpty(str)) return d;
@@ -974,7 +991,7 @@ namespace KeePass.Util.Spr
 				string[] vKvp = strOption.Split(vSplitKvp);
 				if(vKvp.Length != 2) continue;
 
-				string strKey = (vKvp[0] ?? string.Empty).Trim().ToLower();
+				string strKey = (vKvp[0] ?? string.Empty).Trim().ToLowerInvariant();
 				string strValue = (vKvp[1] ?? string.Empty).Trim();
 
 				d[strKey] = strValue;
@@ -983,13 +1000,13 @@ namespace KeePass.Util.Spr
 			return d;
 		}
 
-		private static string GetParam(Dictionary<string, string> d,
+		internal static string GetParam(Dictionary<string, string> d,
 			string strName, string strDefaultValue)
 		{
 			if(d == null) { Debug.Assert(false); return strDefaultValue; }
 			if(strName == null) { Debug.Assert(false); return strDefaultValue; }
 
-			Debug.Assert(strName == strName.ToLower());
+			Debug.Assert(strName == strName.ToLowerInvariant());
 
 			string strValue;
 			if(d.TryGetValue(strName, out strValue)) return strValue;
