@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2020 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -43,7 +43,8 @@ namespace KeePassLib.Utility
 	{
 		private const string AppXDoTool = "xdotool";
 
-		private static Dictionary<uint, bool> g_dForceReq = new Dictionary<uint, bool>();
+		private static readonly Dictionary<uint, bool> g_dForceReq =
+			new Dictionary<uint, bool>();
 		private static Thread g_thFixClip = null;
 		// private static Predicate<IntPtr> g_fOwnWindow = null;
 
@@ -51,11 +52,11 @@ namespace KeePassLib.Utility
 		private static DebugBreakTraceListener g_tlBreak = null;
 #endif
 
-		private static bool? g_bReq = null;
+		private static bool? g_obReq = null;
 		public static bool IsRequired()
 		{
-			if(!g_bReq.HasValue) g_bReq = NativeLib.IsUnix();
-			return g_bReq.Value;
+			if(!g_obReq.HasValue) g_obReq = NativeLib.IsUnix();
+			return g_obReq.Value;
 		}
 
 		// 106:
@@ -95,12 +96,19 @@ namespace KeePassLib.Utility
 		//   Timer causes 100% CPU load.
 		//   https://sourceforge.net/p/keepass/bugs/1527/
 		// 1530:
-		//   Mono's clipboard functions don't work properly.
+		//   Mono's clipboard functions don't work properly; use other in thread.
+		//   See also 1613.
 		//   https://sourceforge.net/p/keepass/bugs/1530/
+		//   https://bugzilla.redhat.com/show_bug.cgi?id=2052696
 		// 1574:
-		//   Finalizer of NotifyIcon throws on Mac OS X.
+		//   Finalizer of NotifyIcon throws on MacOS.
 		//   See also 1354.
 		//   https://sourceforge.net/p/keepass/bugs/1574/
+		// 1613:
+		//   Mono's clipboard functions don't work properly; use other.
+		//   See also 1530.
+		//   https://sourceforge.net/p/keepass/feature-requests/1613/
+		//   https://bugzilla.redhat.com/show_bug.cgi?id=2052696
 		// 1632:
 		//   RichTextBox rendering bug for bold/italic text.
 		//   https://sourceforge.net/p/keepass/bugs/1632/
@@ -116,10 +124,16 @@ namespace KeePassLib.Utility
 		// 1760:
 		//   Input focus is not restored when activating a form.
 		//   https://sourceforge.net/p/keepass/bugs/1760/
+		// 1976:
+		//   Input focus cannot be set after unlocking.
+		//   https://sourceforge.net/p/keepass/bugs/1976/
 		// 2140:
 		//   Explicit control focusing is ignored.
 		//   https://sourceforge.net/p/keepass/feature-requests/2140/
-		// 5795: [Fixed]
+		// 2247:
+		//   Form size increases when calling ResumeLayout.
+		//   https://sourceforge.net/p/keepass/bugs/2247/
+		// 5795:
 		//   Text in input field is incomplete.
 		//   https://bugzilla.xamarin.com/show_bug.cgi?id=5795
 		//   https://sourceforge.net/p/keepass/discussion/329220/thread/d23dc88b/
@@ -140,12 +154,22 @@ namespace KeePassLib.Utility
 		//   PictureBox not rendered when bitmap height >= control height.
 		//   https://bugzilla.xamarin.com/show_bug.cgi?id=12525
 		//   https://sourceforge.net/p/keepass/discussion/329220/thread/54f61e9a/
+		// 19836:
+		//   URLs/documents cannot be opened using Process.Start anymore
+		//   (even when UseShellExecute = true).
+		//   https://github.com/mono/mono/issues/19836
 		// 100001:
 		//   Control locations/sizes are invalid/unexpected.
 		//   [NoRef]
 		// 100002:
 		//   TextChanged event isn't raised when the formatting changes.
 		//   [NoRef]
+		// 100003:
+		//   Icon.ExtractAssociatedIcon always returns the same icon.
+		//   [NoRef]
+		// 100004:
+		//   Use native Argon2 implementation.
+		//   [NoRef]
 		// 190417:
 		//   Mono's Process.Start method replaces '\\' by '/'.
 		//   https://github.com/mono/mono/blob/master/mono/metadata/w32process-unix.c
@@ -164,7 +188,7 @@ namespace KeePassLib.Utility
 		// 686017:
 		//   Minimum sizes must be enforced.
 		//   https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=686017
-		// 688007: [Fixed]
+		// 688007:
 		//   Credentials are required for anonymous web requests.
 		//   https://bugzilla.novell.com/show_bug.cgi?id=688007
 		//   https://sourceforge.net/p/keepass/bugs/1950/
@@ -197,6 +221,8 @@ namespace KeePassLib.Utility
 			bool bForce;
 			if(g_dForceReq.TryGetValue(uBugID, out bForce)) return bForce;
 
+			if((uBugID == 1530) || (uBugID == 1613)) return false;
+
 			ulong v = NativeLib.MonoVersion;
 			if(v == 0) return true;
 
@@ -215,6 +241,14 @@ namespace KeePassLib.Utility
 			return b;
 		}
 
+		// Public for plugins
+		public static void SetEnabled(uint uBugID, bool? obEnabled)
+		{
+			if(obEnabled.HasValue)
+				g_dForceReq[uBugID] = obEnabled.Value;
+			else g_dForceReq.Remove(uBugID);
+		}
+
 		internal static void SetEnabled(string strIDs, bool bEnabled)
 		{
 			if(string.IsNullOrEmpty(strIDs)) return;
@@ -226,7 +260,7 @@ namespace KeePassLib.Utility
 
 				uint uID;
 				if(StrUtil.TryParseUInt(strID.Trim(), out uID))
-					g_dForceReq[uID] = bEnabled;
+					SetEnabled(uID, bEnabled);
 			}
 		}
 
@@ -323,7 +357,8 @@ namespace KeePassLib.Utility
 				if(strHandle.Length == 0) { Debug.Assert(false); return false; }
 
 				// IntPtr h = new IntPtr(long.Parse(strHandle));
-				long.Parse(strHandle); // Validate
+				long l; // Validate
+				if(!long.TryParse(strHandle, out l)) { Debug.Assert(false); return false; }
 
 				// Detection of own windows based on Form.Handle
 				// comparisons doesn't work reliably (Mono's handles
@@ -456,7 +491,7 @@ namespace KeePassLib.Utility
 			return (pi.GetValue(c, null) as EventHandlerList);
 		}
 
-		private static Dictionary<object, MwaHandlerInfo> m_dictHandlers =
+		private static readonly Dictionary<object, MwaHandlerInfo> g_dHandlers =
 			new Dictionary<object, MwaHandlerInfo>();
 		private static void ApplyToButton(Button btn, Form fContext)
 		{
@@ -469,7 +504,7 @@ namespace KeePassLib.Utility
 			Delegate fnClick = ehl[objClickEvent]; // May be null
 
 			EventHandler fnOvr = new EventHandler(MonoWorkarounds.OnButtonClick);
-			m_dictHandlers[btn] = new MwaHandlerInfo(fnClick, fnOvr, dr, fContext);
+			g_dHandlers[btn] = new MwaHandlerInfo(fnClick, fnOvr, dr, fContext);
 
 			btn.DialogResult = DialogResult.None;
 			if(fnClick != null) ehl.RemoveHandler(objClickEvent, fnClick);
@@ -479,13 +514,13 @@ namespace KeePassLib.Utility
 		private static void ReleaseControl(Control c, Form fContext)
 		{
 			Button btn = (c as Button);
-			if(btn != null) ReleaseButton(btn, fContext);
+			if(btn != null) ReleaseButton(btn);
 		}
 
-		private static void ReleaseButton(Button btn, Form fContext)
+		private static void ReleaseButton(Button btn)
 		{
 			MwaHandlerInfo hi;
-			m_dictHandlers.TryGetValue(btn, out hi);
+			g_dHandlers.TryGetValue(btn, out hi);
 			if(hi == null) return;
 
 			object objClickEvent;
@@ -497,7 +532,7 @@ namespace KeePassLib.Utility
 				ehl[objClickEvent] = hi.FunctionOriginal;
 
 			btn.DialogResult = hi.Result;
-			m_dictHandlers.Remove(btn);
+			g_dHandlers.Remove(btn);
 		}
 
 		private static void OnButtonClick(object sender, EventArgs e)
@@ -506,7 +541,7 @@ namespace KeePassLib.Utility
 			if(btn == null) { Debug.Assert(false); return; }
 
 			MwaHandlerInfo hi;
-			m_dictHandlers.TryGetValue(btn, out hi);
+			g_dHandlers.TryGetValue(btn, out hi);
 			if(hi == null) { Debug.Assert(false); return; }
 
 			Form f = hi.FormContext;
