@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ namespace KeePassLib.Utility
 {
 	public static class TypeOverridePool
 	{
-		private static Dictionary<Type, GFunc<object>> g_d =
+		private static readonly Dictionary<Type, GFunc<object>> g_d =
 			new Dictionary<Type, GFunc<object>>();
 
 		public static void Register(Type t, GFunc<object> f)
